@@ -38,7 +38,7 @@ SKGTipOfDayBoardWidget::SKGTipOfDayBoardWidget(SKGDocument* iDocument)
     QFrame* f = new QFrame();
     ui.setupUi(f);
     setMainWidget(f);
-    ui.kIcon->setIcon(QIcon::fromTheme("ktip"));
+    ui.kIcon->setIcon(SKGServices::fromTheme("ktip"));
 
     onModified();
 
