@@ -99,7 +99,7 @@ bool SKGBookmarkPlugin::setupActions(SKGDocument* iDocument, const QStringList&
     registerGlobalAction("go_home", goHomeAction);
 
     // Bookmark
-    KToolBarPopupAction* actBookmark = new KToolBarPopupAction(QIcon::fromTheme("bookmark-new-list"), i18nc("Verb, action to display bookmarks", "Bookmarks"), this);
+    KToolBarPopupAction* actBookmark = new KToolBarPopupAction(SKGServices::fromTheme("bookmark-new-list"), i18nc("Verb, action to display bookmarks", "Bookmarks"), this);
     connect(actBookmark, &KToolBarPopupAction::triggered, this, &SKGBookmarkPlugin::onOpenBookmark);
     m_bookmarkMenu = static_cast<QMenu*>(actBookmark->menu());
     if (m_bookmarkMenu) {
@@ -346,7 +346,7 @@ void SKGBookmarkPlugin::onShowBookmarkMenu()
             if (act) {
                 callerMenu->addAction(act);
                 act->setText(i18nc("Action", "Open all"));
-                act->setIcon(QIcon::fromTheme("quickopen"));
+                act->setIcon(SKGServices::fromTheme("quickopen"));
                 act->setData(idParent);
                 connect(act, &QAction::triggered, this, &SKGBookmarkPlugin::onOpenBookmark);
             }
@@ -356,7 +356,7 @@ void SKGBookmarkPlugin::onShowBookmarkMenu()
                 if (act2) {
                     callerMenu->addAction(act2);
                     act2->setText(i18nc("Action", "Bookmark current page here"));
-                    act2->setIcon(QIcon::fromTheme("list-add"));
+                    act2->setIcon(SKGServices::fromTheme("list-add"));
                     act2->setData(idParent);
 
                     connect(act2, &QAction::triggered, this, &SKGBookmarkPlugin::onAddBookmark);
