@@ -57,8 +57,8 @@ SKGBookmarkPluginDockWidget::SKGBookmarkPluginDockWidget(SKGDocument* iDocument)
     ui.kBookmarksList->setAnimated(false);  // Not compatible with double click
     ui.kBookmarksList->setEditTriggers(QAbstractItemView::NoEditTriggers);
 
-    ui.kTools->setIcon(QIcon::fromTheme("configure"));
-    QTimer::singleShot(200, Qt::CoarseTimer, this, SLOT(initMenu()));
+    ui.kTools->setIcon(SKGServices::fromTheme("configure"));
+    QTimer::singleShot(200, Qt::CoarseTimer, this, &SKGBookmarkPluginDockWidget::initMenu);
 
     ui.kBookmarksList->setContextMenuPolicy(Qt::CustomContextMenu);
     connect(ui.kBookmarksList, &SKGTreeView::customContextMenuRequested, this, &SKGBookmarkPluginDockWidget::showMenu);
@@ -111,41 +111,41 @@ void SKGBookmarkPluginDockWidget::initMenu()
     if (!m_mainMenu) {
         // Build contextual menu
         m_mainMenu = new QMenu(ui.kBookmarksList);
-        QAction* actExpandAll = m_mainMenu->addAction(QIcon::fromTheme("format-indent-more"), i18nc("Noun, user action", "Expand all"));
+        QAction* actExpandAll = m_mainMenu->addAction(SKGServices::fromTheme("format-indent-more"), i18nc("Noun, user action", "Expand all"));
         connect(actExpandAll, &QAction::triggered, ui.kBookmarksList, &SKGTreeView::expandAll);
 
-        QAction* actCollapseAll = m_mainMenu->addAction(QIcon::fromTheme("format-indent-less"), i18nc("Noun, user action", "Collapse all"));
+        QAction* actCollapseAll = m_mainMenu->addAction(SKGServices::fromTheme("format-indent-less"), i18nc("Noun, user action", "Collapse all"));
         connect(actCollapseAll, &QAction::triggered, ui.kBookmarksList, &SKGTreeView::collapseAll);
         ui.kBookmarksList->insertAction(0, actCollapseAll);
 
         m_mainMenu->addSeparator();
 
-        m_actAddBookmark = m_mainMenu->addAction(QIcon::fromTheme("list-add"), i18nc("Verb", "Bookmark current page"));
+        m_actAddBookmark = m_mainMenu->addAction(SKGServices::fromTheme("list-add"), i18nc("Verb", "Bookmark current page"));
         connect(m_actAddBookmark, &QAction::triggered, this, &SKGBookmarkPluginDockWidget::onAddBookmark);
 
-        m_actAddBookmarks = m_mainMenu->addAction(QIcon::fromTheme("list-add"), i18nc("Verb", "Bookmark all pages"));
+        m_actAddBookmarks = m_mainMenu->addAction(SKGServices::fromTheme("list-add"), i18nc("Verb", "Bookmark all pages"));
         connect(m_actAddBookmarks, &QAction::triggered, this, &SKGBookmarkPluginDockWidget::onAddBookmarks);
 
-        m_actAddBookmarkGroup = m_mainMenu->addAction(QIcon::fromTheme("folder-new"), i18nc("Verb", "Add bookmark group"));
+        m_actAddBookmarkGroup = m_mainMenu->addAction(SKGServices::fromTheme("folder-new"), i18nc("Verb", "Add bookmark group"));
         connect(m_actAddBookmarkGroup, &QAction::triggered, this, &SKGBookmarkPluginDockWidget::onAddBookmarkGroup);
 
         m_mainMenu->addSeparator();
 
-        m_actDelete = m_mainMenu->addAction(QIcon::fromTheme("edit-delete"), i18nc("Verb, delete an item", "Delete"));
+        m_actDelete = m_mainMenu->addAction(SKGServices::fromTheme("edit-delete"), i18nc("Verb, delete an item", "Delete"));
         connect(m_actDelete, &QAction::triggered, this, &SKGBookmarkPluginDockWidget::onRemoveBookmark);
 
         m_mainMenu->addSeparator();
 
-        m_actSetAutostart = m_mainMenu->addAction(QIcon::fromTheme("user-online"), i18nc("Verb, automatically load when the application is started", "Autostart"));
+        m_actSetAutostart = m_mainMenu->addAction(SKGServices::fromTheme("user-online"), i18nc("Verb, automatically load when the application is started", "Autostart"));
         connect(m_actSetAutostart, &QAction::triggered, this, &SKGBookmarkPluginDockWidget::onSetAutostart);
 
-        m_actUnsetAutostart = m_mainMenu->addAction(QIcon::fromTheme("user-offline"), i18nc("Verb", "Remove Autostart"));
+        m_actUnsetAutostart = m_mainMenu->addAction(SKGServices::fromTheme("user-offline"), i18nc("Verb", "Remove Autostart"));
         connect(m_actUnsetAutostart, &QAction::triggered, this, &SKGBookmarkPluginDockWidget::onUnsetAutostart);
 
-        m_actRename = m_mainMenu->addAction(QIcon::fromTheme("edit-rename"), i18nc("Verb, change the name of an item", "Rename"));
+        m_actRename = m_mainMenu->addAction(SKGServices::fromTheme("edit-rename"), i18nc("Verb, change the name of an item", "Rename"));
         connect(m_actRename, &QAction::triggered, this, &SKGBookmarkPluginDockWidget::onRenameBookmark);
 
-        m_actChangeIcon = m_mainMenu->addAction(QIcon::fromTheme("view-media-visualization"), i18nc("Verb, change the icon of an item", "Change icon..."));
+        m_actChangeIcon = m_mainMenu->addAction(SKGServices::fromTheme("view-media-visualization"), i18nc("Verb, change the icon of an item", "Change icon..."));
         connect(m_actChangeIcon, &QAction::triggered, this, &SKGBookmarkPluginDockWidget::onChangeIconBookmark);
 
         m_mainMenu->addSeparator();
