@@ -74,7 +74,7 @@ protected:
      * When resizeEvent() is called, the widget already has its new geometry. The old size is accessible through QResizeEvent::oldSize().
      * @param iEvent the event pointer
      */
-    virtual void resizeEvent(QResizeEvent* iEvent);
+    virtual void resizeEvent(QResizeEvent* iEvent) Q_DECL_OVERRIDE;
 
 public Q_SLOTS:
     /**
