@@ -83,6 +83,13 @@ public:
      */
     virtual QWidget* zoomableWidget() Q_DECL_OVERRIDE;
 
+    /**
+     * Get the printable widgets.
+     * The default implementation returns the main widget.
+     * @return the printable widgets.
+     */
+    virtual QList<QWidget*> printableWidgets() Q_DECL_OVERRIDE;
+
 protected:
     /**
      * Event filtering
@@ -90,7 +97,7 @@ protected:
      * @param iEvent event
      * @return In your reimplementation of this function, if you want to filter the event out, i.e. stop it being handled further, return true; otherwise return false.
      */
-    virtual bool eventFilter(QObject* iObject, QEvent* iEvent);
+    virtual bool eventFilter(QObject* iObject, QEvent* iEvent) Q_DECL_OVERRIDE;
 
 public Q_SLOTS:
     /**
