@@ -67,7 +67,7 @@ bool SKGDeletePlugin::setupActions(SKGDocument* iDocument, const QStringList& iA
     // Menu
     QStringList tmp;
     m_currentDocument->getDistinctValues("sqlite_master", "name", "type='table' AND name!='parameters'", tmp);
-    QAction* actDelete = new QAction(QIcon::fromTheme("edit-delete"), i18nc("Verb, delete an item", "Delete"), this);
+    QAction* actDelete = new QAction(SKGServices::fromTheme("edit-delete"), i18nc("Verb, delete an item", "Delete"), this);
     connect(actDelete, &QAction::triggered, this, &SKGDeletePlugin::onDelete);
     actionCollection()->setDefaultShortcut(actDelete, Qt::Key_Delete);
     registerGlobalAction("edit_delete", actDelete, tmp, 1, -1, 200);
