@@ -52,11 +52,6 @@ public:
      */
     virtual bool setupActions(SKGDocument* iDocument, const QStringList& iArgument) Q_DECL_OVERRIDE;
 
-    /**
-     * Must be modified to refresh widgets after a modification.
-     */
-    virtual void refresh() Q_DECL_OVERRIDE;
-
     /**
      * The title of the plugin.
      * @return The title of the plugin
@@ -74,8 +69,6 @@ private Q_SLOTS:
 private:
     Q_DISABLE_COPY(SKGDeletePlugin)
 
-    QAction* m_deleteAction;
-
     SKGDocument* m_currentDocument;
 };
 
