@@ -90,7 +90,7 @@ bool SKGFilePlugin::setupActions(SKGDocument* iDocument, const QStringList& iArg
     registerGlobalAction("file_save", m_saveAction);
     registerGlobalAction("file_save_as", KStandardAction::saveAs(this, SLOT(onSaveAs()), actionCollection()));
 
-    QAction* actChangePassword = new QAction(QIcon::fromTheme("document-encrypt"),  i18nc("Action allowing the user to change his document password", "Change password..."), this);
+    QAction* actChangePassword = new QAction(SKGServices::fromTheme("document-encrypt"),  i18nc("Action allowing the user to change his document password", "Change password..."), this);
     connect(actChangePassword, &QAction::triggered, this, &SKGFilePlugin::onChangePassword);
     actionCollection()->setDefaultShortcut(actChangePassword, Qt::CTRL + Qt::Key_K);
     registerGlobalAction("file_change_password", actChangePassword);
@@ -386,7 +386,7 @@ void SKGFilePlugin::onOpen(const QUrl& iUrl)
             if (QFile(tmpFile).exists()) {
                 KMessageWidget* msg = SKGMainPanel::getMainPanel()->displayMessage(i18nc("Warning message", "Your document has been restored from its temporary file. You can decide to reopen the original document."), SKGDocument::Warning);
                 QAction* reopen = new QAction(i18nc("Noun", "Reopen"), msg);
-                reopen->setIcon(QIcon::fromTheme("quickopen"));
+                reopen->setIcon(SKGServices::fromTheme("quickopen"));
                 reopen->setData(fileName);
                 msg->addAction(reopen);
                 connect(reopen, &QAction::triggered, this, &SKGFilePlugin::onReOpen);
@@ -528,7 +528,7 @@ void SKGFilePlugin::onOpen(const QUrl& iUrl)
 #ifdef Q_OS_UNIX
             if (err.getReturnCode() == ERR_CORRUPTION) {
                 recovery = new QAction(i18nc("Noun", "Try a recovery"), this);
-                recovery->setIcon(QIcon::fromTheme("games-solve"));
+                recovery->setIcon(SKGServices::fromTheme("games-solve"));
                 recovery->setData(SKGServices::stringsToCsv(QStringList() << fileName << pwd));
                 connect(recovery, &QAction::triggered, this, &SKGFilePlugin::onRecover);
             }
@@ -552,7 +552,7 @@ void SKGFilePlugin::onRecover()
             // Display recovery message
             KMessageWidget* msg = SKGMainPanel::getMainPanel()->displayMessage(i18nc("Positive message", "Your document has been recovered here: %1\nTake care the recovery could be not perfect", recoveredFileName), SKGDocument::Positive);
             QAction* reopen = new QAction(i18nc("Noun", "Open the recovered file"), msg);
-            reopen->setIcon(QIcon::fromTheme("quickopen"));
+            reopen->setIcon(SKGServices::fromTheme("quickopen"));
             reopen->setData(recoveredFileName);
             msg->addAction(reopen);
             connect(reopen, &QAction::triggered, this, &SKGFilePlugin::onReOpen);
