@@ -62,14 +62,14 @@ bool SKGHighlightPlugin::setupActions(SKGDocument* iDocument, const QStringList&
     // ------------
     QStringList tmp;
     m_currentDocument->getDistinctValues("sqlite_master", "name", "type='table' AND sql LIKE '%t_bookmarked%'", tmp);
-    QAction* actSwitchHighLight = new QAction(QIcon::fromTheme("bookmarks"), i18nc("Verb", "Switch highlight"), this);
+    QAction* actSwitchHighLight = new QAction(SKGServices::fromTheme("bookmarks"), i18nc("Verb", "Switch highlight"), this);
     connect(actSwitchHighLight, &QAction::triggered, this, &SKGHighlightPlugin::onSwitchHighLight);
     actionCollection()->setDefaultShortcut(actSwitchHighLight, Qt::CTRL + Qt::Key_H);
     registerGlobalAction("edit_switch_highlight", actSwitchHighLight, tmp, 1, -1, 301);
 
     // ------------
     m_currentDocument->getDistinctValues("sqlite_master", "name", "type='table' AND sql LIKE '%t_close%'", tmp);
-    QAction* actSwitchClose = new QAction(QIcon::fromTheme("dialog-close"), i18nc("Verb", "Switch close"), this);
+    QAction* actSwitchClose = new QAction(SKGServices::fromTheme("dialog-close"), i18nc("Verb", "Switch close"), this);
     connect(actSwitchClose, &QAction::triggered, this, &SKGHighlightPlugin::onSwitchClose);
     registerGlobalAction("edit_switch_close", actSwitchClose, tmp, 1, -1, 301);
 
