@@ -56,9 +56,9 @@ SKGMonthlyPluginWidget::SKGMonthlyPluginWidget(SKGDocument* iDocument)
     ui.kMonth->setMode(SKGSimplePeriodEdit::PREVIOUS_PERIODS);
     ui.kDeleteTemplate->hide();
 
-    ui.kRefresh->setIcon(QIcon::fromTheme("view-refresh"));
-    ui.kGetNewHotStuff->setIcon(QIcon::fromTheme("get-hot-new-stuff"));
-    ui.kDeleteTemplate->setIcon(QIcon::fromTheme("edit-delete"));
+    ui.kRefresh->setIcon(SKGServices::fromTheme("view-refresh"));
+    ui.kGetNewHotStuff->setIcon(SKGServices::fromTheme("get-hot-new-stuff"));
+    ui.kDeleteTemplate->setIcon(SKGServices::fromTheme("edit-delete"));
 
     QRegExpValidator* newValidator = new QRegExpValidator(QRegExp("^[\\w\\s]+$"), this);
     ui.kTemplate->setValidator(newValidator);
