@@ -177,11 +177,18 @@ void SKGPrintPlugin::print(QPrinter* iPrinter)
                     for (int p = 1; !err && p <= pageCopies; ++p) {
                         SKGTabPage* page = static_cast<SKGTabPage*>(tabs->widget(pageToTreat - 1));
                         if (page) {
+                            // Add page break if needed
+                            if (!html.isEmpty()) {
+                                html = html % "<div style=\"page-break-after:always\"></div>";
+                            }
+
+                            // Add widgets
                             QList<QWidget*> widgets = page->printableWidgets();
                             int nbw = widgets.count();
                             for (int j = 0; !err && j < nbw; ++j) {
                                 QWidget* w = widgets.at(j);
                                 if (w) {
+                                    // Add widget
                                     SKGTreeView* tw = qobject_cast< SKGTreeView* >(w);
                                     tw = NULL;
                                     if (tw) {
@@ -229,16 +236,9 @@ void SKGPrintPlugin::print(QPrinter* iPrinter)
         // Print
         QWebView toPrint;
         toPrint.setHtml(html);
+        toPrint.setFixedSize(QSize(iPrinter->width(), iPrinter->height()));
         qApp->processEvents(QEventLoop::AllEvents, 5000);
 
-        // Reset printer option because already treated
-        iPrinter->setPrintRange(QPrinter::AllPages);
-        iPrinter->setFromTo(1, nbpages);
-        iPrinter->setCollateCopies(false);
-        iPrinter->setPageOrder(QPrinter::FirstPageFirst);
-        iPrinter->setNumCopies(1);
-        iPrinter->setPrintProgram(qApp->applicationName());
-        iPrinter->setCreator(qApp->applicationName());
         toPrint.print(iPrinter);
 
         // status bar
