@@ -123,7 +123,7 @@ bool SKGPropertiesPlugin::setupActions(SKGDocument* iDocument, const QStringList
     // Menu
     QStringList tmp;
     m_currentDocument->getDistinctValues("sqlite_master", "name", "type='table' AND name NOT LIKE 'doctransaction%'", tmp);
-    KToolBarPopupAction* actAddProperty = new KToolBarPopupAction(QIcon::fromTheme(icon()), i18nc("Allows user to add a user defined property on an object", "Add property"), this);
+    KToolBarPopupAction* actAddProperty = new KToolBarPopupAction(SKGServices::fromTheme(icon()), i18nc("Allows user to add a user defined property on an object", "Add property"), this);
     m_addPropertyMenu = static_cast<QMenu*>(actAddProperty->menu());
     connect(m_addPropertyMenu, &QMenu::aboutToShow, this, &SKGPropertiesPlugin::onShowAddPropertyMenu);
     actAddProperty->setStickyMenu(false);
@@ -187,7 +187,7 @@ void SKGPropertiesPlugin::onDownloadAndAddBills()
                 QProcess p;
                 p.start(cmd);
                 if (!p.waitForFinished(60000) || p.exitCode() != 0) {
-                    err.setReturnCode(ERR_FAIL).setMessage(i18nc("Error message",  "The following command line failed:\n'%1'", cmd));
+                    err.setReturnCode(ERR_FAIL).setMessage(i18nc("Error message",  "The following command line failed with code %2:\n'%1'", cmd, p.exitCode()));
                 } else {
                     IFOKDO(err, m_currentDocument->stepForward(2 * i))
 
@@ -230,7 +230,7 @@ void SKGPropertiesPlugin::onShowAddPropertyMenu()
 
             // Create actions
             int nb = listTmp.count();
-            QIcon iconp = QIcon::fromTheme(icon());
+            QIcon iconp = SKGServices::fromTheme(icon());
             for (int i = 1; i < nb; ++i) {
                 // Should the string below be translated ??? It contains no word...
                 QAction* act = m_addPropertyMenu->addAction(iconp, i18nc("Add a property (attribute=value)", "Add %1=%2", listTmp.at(i).at(0), listTmp.at(i).at(1)));
