@@ -54,11 +54,11 @@ SKGPropertiesPluginDockWidget::SKGPropertiesPluginDockWidget(SKGDocument* iDocum
     ui.kRemove->setMaximumWidth(ui.kRemove->height());
     ui.kSelectFile->setMaximumWidth(ui.kSelectFile->height());
 
-    ui.kAdd->setIcon(QIcon::fromTheme("list-add"));
-    ui.kRename->setIcon(QIcon::fromTheme("dialog-ok-apply"));
-    ui.kRemove->setIcon(QIcon::fromTheme("list-remove"));
-    ui.kSelectFile->setIcon(QIcon::fromTheme("document-open"));
-    ui.kOpenBtn->setIcon(QIcon::fromTheme("quickopen"));
+    ui.kAdd->setIcon(SKGServices::fromTheme("list-add"));
+    ui.kRename->setIcon(SKGServices::fromTheme("dialog-ok"));
+    ui.kRemove->setIcon(SKGServices::fromTheme("list-remove"));
+    ui.kSelectFile->setIcon(SKGServices::fromTheme("document-open"));
+    ui.kOpenBtn->setIcon(SKGServices::fromTheme("quickopen"));
 
     ui.kForCmb->addItem(i18n("Selection"));
     ui.kForCmb->addItem(i18n("All"));
@@ -169,48 +169,17 @@ void SKGPropertiesPluginDockWidget::onSelectionChanged()
     ui.kRemove->setEnabled(nbSelected > 0);
     if (nbSelected > 0) {
         SKGObjectBase::SKGListSKGObjectBase objs = getSelectedObjects();
-        SKGObjectBase obj = objs.at(0);
+        SKGPropertyObject obj(objs.at(0));
         ui.kAttribute->setText(obj.getAttribute("t_name"));
         ui.kValue->setText(obj.getAttribute("t_value"));
 
         if (nbSelected == 1) {
-            QStringList uuid = obj.getAttribute("t_uuid_parent").split('-');
-            if (uuid.count() == 2) {
-                SKGObjectBase p(getDocument(), uuid.at(1), SKGServices::stringToInt(uuid.at(0)));
-                QVariant blob = p.getPropertyBlob(obj.getAttribute("t_name"));
+            QUrl u = obj.getUrl(true);
 
-                // Is it a copied file ?
-                if (!blob.isNull()) {
-                    // Yes, this is a file
-                    QByteArray blob_bytes = blob.toByteArray();
-
-                    // Save temporary file
-                    QString fileName = QDir::tempPath() % '/' % obj.getAttribute("t_value");
-
-                    QFile file(fileName);
-                    file.setPermissions(QFile::ReadOwner | QFile::WriteOwner);
-                    if (file.open(QIODevice::WriteOnly)) {
-                        file.write(blob_bytes);
-                        file.flush();
-                        file.close();
-                        file.setPermissions(QFile::ReadOwner);  // To be sure that no modifications are done
-
-                        ui.kPicture->show();
-                        ui.kOpenBtn->show();
-                        ui.kPicture->showPreview(QUrl::fromLocalFile(fileName));
-                    }
-                } else if (QFile(obj.getAttribute("t_value")).exists()) {
-                    // Is it a linked file ? Yes
-                    ui.kPicture->show();
-                    ui.kOpenBtn->show();
-                    ui.kPicture->showPreview(QUrl::fromLocalFile(obj.getAttribute("t_value")));
-                } else {
-                    // Is it a linked file ? No, Is it a http url ?
-                    QUrl url(obj.getAttribute("t_value"));
-                    if (!url.scheme().isEmpty()) {
-                        ui.kOpenBtn->show();
-                    }
-                }
+            ui.kOpenBtn->show();
+            if (u.scheme() == "file") {
+                ui.kPicture->show();
+                ui.kPicture->showPreview(u);
             }
         }
     }
@@ -224,40 +193,19 @@ void SKGPropertiesPluginDockWidget::onOpenFile()
 {
     SKGTRACEINFUNC(10);
     int nbSelected = getNbSelectedObjects();
-    if (nbSelected > 0) {
+    if (nbSelected == 1) {
+        QApplication::setOverrideCursor(QCursor(Qt::WaitCursor));
         SKGObjectBase::SKGListSKGObjectBase objs = getSelectedObjects();
-        if (nbSelected == 1) {
-            SKGObjectBase obj = objs.at(0);
+        SKGPropertyObject obj(objs.at(0));
+        QUrl url = obj.getUrl(true);
 
-            QApplication::setOverrideCursor(QCursor(Qt::WaitCursor));
-            QStringList uuid = obj.getAttribute("t_uuid_parent").split('-');
-            if (uuid.count() == 2) {
-                SKGObjectBase p(getDocument(), uuid.at(1), SKGServices::stringToInt(uuid.at(0)));
-                QVariant blob = p.getPropertyBlob(obj.getAttribute("t_name"));
-                // Is it a copied file ?
-                if (!blob.isNull()) {
-                    // Yes, this is a file
-                    // Display temporary file
-                    QString fileName = QDir::tempPath() % '/' % obj.getAttribute("t_value");
-                    if (!QDesktopServices::openUrl(QUrl::fromLocalFile(fileName))) {
-                        QString fileNameToSave = SKGMainPanel::getSaveFileName("kfiledialog:///IMPEXP", "" , SKGMainPanel::getMainPanel());
-                        if (!fileNameToSave.isEmpty()) {
-                            QFile(fileName).copy(fileNameToSave);
-                        }
-                    }
-                } else if (QFile().exists(obj.getAttribute("t_value"))) {
-                    // Is it a linked file? Yes
-                    QDesktopServices::openUrl(QUrl::fromLocalFile(obj.getAttribute("t_value")));
-                } else {
-                    // Is it a linked file?  No, Is it a http url ?
-                    QUrl url = QUrl::fromLocalFile(obj.getAttribute("t_value"));
-                    if (!url.scheme().isEmpty()) {
-                        QDesktopServices::openUrl(url);
-                    }
-                }
+        if (!url.scheme().isEmpty() && !QDesktopServices::openUrl(url)) {
+            QString fileNameToSave = SKGMainPanel::getSaveFileName("kfiledialog:///IMPEXP", "" , SKGMainPanel::getMainPanel());
+            if (!fileNameToSave.isEmpty()) {
+                QFile(url.toLocalFile()).copy(fileNameToSave);
             }
-            QApplication::restoreOverrideCursor();
         }
+        QApplication::restoreOverrideCursor();
     }
 
     if (ui.kView->isAutoResized()) {
