@@ -72,12 +72,12 @@ bool SKGUndoRedoPlugin::setupActions(SKGDocument* iDocument, const QStringList&
     setXMLFile("skg_undoredo.rc");
 
     // Menu
-    m_undoSaveAction = new QAction(QIcon::fromTheme("document-revert"), i18nc("Verb, action to cancel previous action", "Revert document"), this);
+    m_undoSaveAction = new QAction(SKGServices::fromTheme("document-revert"), i18nc("Verb, action to cancel previous action", "Revert document"), this);
     connect(m_undoSaveAction, &QAction::triggered, this, &SKGUndoRedoPlugin::onUndoSave);
     actionCollection()->setDefaultShortcut(m_undoSaveAction, Qt::CTRL + Qt::ALT + Qt::Key_Z);
     registerGlobalAction("edit_undolastsave", m_undoSaveAction);
 
-    m_undoAction = new KToolBarPopupAction(QIcon::fromTheme("edit-undo"), i18nc("Verb, action to cancel previous action", "Undo"), this);
+    m_undoAction = new KToolBarPopupAction(SKGServices::fromTheme("edit-undo"), i18nc("Verb, action to cancel previous action", "Undo"), this);
     connect(m_undoAction, &KToolBarPopupAction::triggered, this, &SKGUndoRedoPlugin::onUndo);
     actionCollection()->setDefaultShortcut(m_undoAction, Qt::CTRL + Qt::Key_Z);
     m_undoAction->setPriority(QAction::LowPriority);
@@ -87,7 +87,7 @@ bool SKGUndoRedoPlugin::setupActions(SKGDocument* iDocument, const QStringList&
     m_undoAction->setData(1);
     registerGlobalAction("edit_undo", m_undoAction);
 
-    m_redoAction = new KToolBarPopupAction(QIcon::fromTheme("edit-redo"), i18nc("Verb, action to redo previous cancelled action", "Redo"), this);
+    m_redoAction = new KToolBarPopupAction(SKGServices::fromTheme("edit-redo"), i18nc("Verb, action to redo previous cancelled action", "Redo"), this);
     connect(m_redoAction, &KToolBarPopupAction::triggered, this, &SKGUndoRedoPlugin::onRedo);
     actionCollection()->setDefaultShortcut(m_redoAction, Qt::CTRL + Qt::SHIFT + Qt::Key_Z);
     m_redoAction->setPriority(QAction::LowPriority);
@@ -98,7 +98,7 @@ bool SKGUndoRedoPlugin::setupActions(SKGDocument* iDocument, const QStringList&
     registerGlobalAction("edit_redo", m_redoAction);
 
     // Menu
-    QAction* act = new QAction(QIcon::fromTheme("edit-clear-history"), i18nc("Verb, action to cancel previous action", "Clear history"), this);
+    QAction* act = new QAction(SKGServices::fromTheme("edit-clear-history"), i18nc("Verb, action to cancel previous action", "Clear history"), this);
     connect(act, &QAction::triggered, this, &SKGUndoRedoPlugin::onClearHistory);
     registerGlobalAction("edit_clear_history", act);
 
@@ -345,7 +345,7 @@ void SKGUndoRedoPlugin::onShowUndoMenu()
             listTmp);
         int nb = listTmp.count();
         for (int i = 1; i < nb; ++i) {
-            QAction* act = m_undoMenu->addAction(listTmp.at(i).at(1) == "Y" ?  QIcon::fromTheme("document-revert") : QIcon::fromTheme("edit-undo"), listTmp.at(i).at(0));
+            QAction* act = m_undoMenu->addAction(listTmp.at(i).at(1) == "Y" ?  SKGServices::fromTheme("document-revert") : SKGServices::fromTheme("edit-undo"), listTmp.at(i).at(0));
             if (act) {
                 act->setData(i);
                 connect(act, &QAction::triggered, this, &SKGUndoRedoPlugin::onUndo);
@@ -387,7 +387,7 @@ void SKGUndoRedoPlugin::onShowRedoMenu()
             listTmp);
         int nb = listTmp.count();
         for (int i = 1; i < nb; ++i) {
-            QAction* act = m_redoMenu->addAction(QIcon::fromTheme("edit-redo"), listTmp.at(i).at(0));
+            QAction* act = m_redoMenu->addAction(SKGServices::fromTheme("edit-redo"), listTmp.at(i).at(0));
             if (act) {
                 act->setData(i);
                 connect(act, &QAction::triggered, this, &SKGUndoRedoPlugin::onRedo);
