@@ -54,7 +54,7 @@ protected:
      * When resizeEvent() is called, the widget already has its new geometry. The old size is accessible through QResizeEvent::oldSize().
      * @param event the event pointer
      */
-    virtual void resizeEvent(QResizeEvent* event);
+    virtual void resizeEvent(QResizeEvent* event) Q_DECL_OVERRIDE;
 
 private Q_SLOTS:
     void onUndoRedo(const QModelIndex& index);
