@@ -215,12 +215,6 @@ SKGError SKGImportPluginCsv::setCSVMapping(const QStringList* iCSVMapping)
     return err;
 }
 
-QStringList SKGImportPluginCsv::getCSVMapping() const
-{
-    SKGTRACEINFUNC(10);
-    return m_csvMapping;
-}
-
 SKGError SKGImportPluginCsv::setCSVHeaderIndex(int iIndex)
 {
     SKGError err;
@@ -304,11 +298,11 @@ SKGError SKGImportPluginCsv::importFile()
         QString postFix = SKGServices::dateToSqlString(now);
 
         // Default mapping
-        if (getCSVMapping().count() == 0) {
+        if (m_csvMapping.count() == 0) {
             err = setCSVMapping(NULL);
             IFOKDO(err, m_importer->getDocument()->sendMessage(i18nc("An information message",  "Use automatic search of the columns")))
         }
-        IFOKDO(err, m_importer->getDocument()->sendMessage(i18nc("An information message",  "Mapping used: %1", getCSVMapping().join("|"))))
+        IFOKDO(err, m_importer->getDocument()->sendMessage(i18nc("An information message",  "Mapping used: %1", m_csvMapping.join("|"))))
 
         // Step 1 done
         IFOKDO(err, m_importer->getDocument()->stepForward(1))
@@ -335,9 +329,9 @@ SKGError SKGImportPluginCsv::importFile()
                 }
 
                 QList<int> amountIndexes;
-                int nb = getCSVMapping().count();
+                int nb = m_csvMapping.count();
                 for (int i = 0; i < nb; ++i) {
-                    if (getCSVMapping()[i] == "amount") {
+                    if (m_csvMapping[i] == "amount") {
                         amountIndexes.push_back(i);
                     }
                 }
@@ -346,9 +340,9 @@ SKGError SKGImportPluginCsv::importFile()
                 // Get data column
                 QStringList dates;
                 QStringList lines;
-                bool modeAutoCreditDebit = (!getCSVMapping().contains("sign") && nbAmount == 2);
+                bool modeAutoCreditDebit = (!m_csvMapping.contains("sign") && nbAmount == 2);
                 IFOK(err) {
-                    int posdate = getCSVMapping().indexOf("date");
+                    int posdate = m_csvMapping.indexOf("date");
                     if (posdate != -1) {
                         QString currentLine;
                         while (!stream.atEnd()) {
@@ -407,12 +401,12 @@ SKGError SKGImportPluginCsv::importFile()
 
                     // Save last mapping used in a settings
                     QString mappingDesc;
-                    int nbMap = getCSVMapping().count();
+                    int nbMap = m_csvMapping.count();
                     for (int i = 0; i < nbMap; ++i) {
                         if (i) {
                             mappingDesc += '|';
                         }
-                        mappingDesc += getCSVMapping().at(i);
+                        mappingDesc += m_csvMapping.at(i);
                     }
                     IFOKDO(err, m_importer->getDocument()->setParameter("SKG_LAST_CSV_MAPPING_USED", mappingDesc))
 
@@ -420,8 +414,8 @@ SKGError SKGImportPluginCsv::importFile()
                     SKGAccountObject defAccount;
                     QMap<int, SKGOperationObject> mapGroup;
                     QMap<int, SKGOperationObject> mapOperation;
-                    bool noUnitColumn = (getCSVMapping().indexOf("unit") == -1);
-                    bool noAccountColumn = (getCSVMapping().indexOf("account") == -1);
+                    bool noUnitColumn = (m_csvMapping.indexOf("unit") == -1);
+                    bool noAccountColumn = (m_csvMapping.indexOf("account") == -1);
                     bool emptyAccount = false;
 
                     for (int i = 0; !err && i < nb2; ++i) {
@@ -448,7 +442,7 @@ SKGError SKGImportPluginCsv::importFile()
 
                         QString skg_op_original_amount;
                         QStringList atts = SKGServices::splitCSVLine(line, getCSVSeparator());
-                        int nbcol = getCSVMapping().count();
+                        int nbcol = m_csvMapping.count();
                         if (atts.count() < nbcol) {
                             err = SKGError(ERR_INVALIDARG, i18nc("Error message", "Invalid number of columns in line %1. Expected %2. Found %3.",
                                                                  headerIndex + i + 1, nbcol, atts.count()));
@@ -461,7 +455,7 @@ SKGError SKGImportPluginCsv::importFile()
                         double sign = (modeAutoCreditDebit ? -1.0 : 1.0);
                         bool amountSet = false;
                         for (int c = 0; !err && c < nbcol; ++c) {
-                            QString col = getCSVMapping()[c];
+                            QString col = m_csvMapping[c];
                             if (!col.isEmpty()) {
                                 QString val;
                                 if (c >= 0 && c < atts.count()) {
@@ -518,7 +512,7 @@ SKGError SKGImportPluginCsv::importFile()
                                 } else if (col == "amount") {
                                     if (!val.isEmpty() && SKGServices::stringToDouble(val) != 0.0 && !amountSet) {
                                         amountSet = true;
-                                        if (getCSVMapping().contains("quantity")) {
+                                        if (m_csvMapping.contains("quantity")) {
                                             // 209705 vvvv
                                             skg_op_original_amount = val;
                                             // 209705 ^^^^
@@ -557,8 +551,8 @@ SKGError SKGImportPluginCsv::importFile()
                                     SKGUnitValueObject unitval;
                                     IFOKDO(err, unit.addUnitValue(unitval))
                                     IFOK(err) {
-                                        int posAmount = getCSVMapping().indexOf("amount");
-                                        int posQuantity = getCSVMapping().indexOf("quantity");
+                                        int posAmount = m_csvMapping.indexOf("amount");
+                                        int posQuantity = m_csvMapping.indexOf("quantity");
                                         if (posAmount != -1 && posQuantity != -1) {
                                             err = unitval.setQuantity(SKGServices::stringToDouble(atts.at(posAmount)) / SKGServices::stringToDouble(atts.at(posQuantity)));
                                         } else {
@@ -612,6 +606,13 @@ SKGError SKGImportPluginCsv::importFile()
                                         SKGCategoryObject Category;
                                         err = SKGCategoryObject::createPathCategory(m_importer->getDocument(), val, Category);
                                         IFOKDO(err, currentSubOperation.setCategory(Category))
+
+                                        IFOK(err && m_csvMapping.indexOf("payee") == -1) {
+                                            SKGPayeeObject payeeObj;
+                                            QString p = m_importer->getDocument()->getCategoryForPayee(val);
+                                            err = SKGPayeeObject::createPayee(m_importer->getDocument(), p, payeeObj);
+                                            IFOKDO(err, currentOperation.setPayee(payeeObj))
+                                        }
                                     }
                                 } else {
                                     // A property
@@ -759,7 +760,7 @@ SKGError SKGImportPluginCsv::importCSVUnit()
             QString unitName = fInfo.baseName();
 
             // Default mapping
-            if (getCSVMapping().count() == 0) {
+            if (m_csvMapping.count() == 0) {
                 err = setCSVMapping(NULL);
                 IFOKDO(err, m_importer->getDocument()->sendMessage(i18nc("An information message",  "Use automatic search of the columns")))
             }
@@ -873,7 +874,7 @@ SKGError SKGImportPluginCsv::importCSVRule()
             QString unitName = fInfo.baseName();
 
             // Default mapping
-            if (getCSVMapping().count() == 0) {
+            if (m_csvMapping.count() == 0) {
                 err = setCSVMapping(NULL);
                 IFOKDO(err, m_importer->getDocument()->sendMessage(i18nc("An information message",  "Use automatic search of the columns")))
             }
