@@ -33,8 +33,9 @@
 #include "skgimportexportmanager.h"
 
 SKGError SKGImportPluginOfx::m_ofxError;
-QList<OfxStatementData> SKGImportPluginOfx::m_ofxInitialBalance;
-
+QStringList SKGImportPluginOfx::m_ofxInitialBalanceName;
+QList<double> SKGImportPluginOfx::m_ofxInitialBalanceAmount;
+QList<QDate> SKGImportPluginOfx::m_ofxInitialBalanceDate;
 
 /**
  * This plugin factory.
@@ -73,7 +74,9 @@ SKGError SKGImportPluginOfx::importFile()
     IFOKDO(err, m_importer->getDocument()->beginTransaction("#INTERNAL#" % i18nc("Import step", "Import %1 file", "OFX")))
     IFOK(err) {
         SKGImportPluginOfx::m_ofxError = SKGError();
-        SKGImportPluginOfx::m_ofxInitialBalance.clear();
+        SKGImportPluginOfx::m_ofxInitialBalanceName.clear();
+        SKGImportPluginOfx::m_ofxInitialBalanceAmount.clear();
+        SKGImportPluginOfx::m_ofxInitialBalanceDate.clear();
 
         try {
             LibofxContextPtr ctx = libofx_get_new_context();
@@ -89,18 +92,13 @@ SKGError SKGImportPluginOfx::importFile()
             IFOKDO(err, SKGImportPluginOfx::m_ofxError) {
                 // This is an option ==> no error management
                 SKGError err2;
-                int nb = SKGImportPluginOfx::m_ofxInitialBalance.count();
+                int nb = SKGImportPluginOfx::m_ofxInitialBalanceName.count();
                 for (int i = 0; !err2 && i < nb; ++i) {
-                    OfxStatementData data = SKGImportPluginOfx::m_ofxInitialBalance.at(i);
-
-                    // Get account
                     SKGAccountObject act;
-                    if (!err2) {
-                        err2 = getAccount(data.account_ptr, m_importer->getDocument(), act);
-                    }
+                    err2 = m_importer->getDocument()->getObject("v_account", "t_number='" % SKGServices::stringToSqlString(m_ofxInitialBalanceName.at(i)) % '\'', act);
 
                     // Date of balance
-                    QDate date = (data.ledger_balance_date_valid == true ? QDateTime::fromTime_t(data.ledger_balance_date).date() : QDate::currentDate());
+                    QDate date = m_ofxInitialBalanceDate.at(i);
 
                     // Get unit
                     SKGUnitObject unit;
@@ -113,7 +111,7 @@ SKGError SKGImportPluginOfx::importFile()
 
                     // Update account
                     if (!err2) {
-                        err2 = act.setInitialBalance(data.ledger_balance - currentAmount, unit);
+                        err2 = act.setInitialBalance(m_ofxInitialBalanceAmount.at(i) - currentAmount, unit);
                     }
                     if (!err2) {
                         err2 = act.save();
@@ -127,32 +125,44 @@ SKGError SKGImportPluginOfx::importFile()
             err = SKGError(ERR_HANDLE, i18nc("Error message", "OFX import failed"));
         }
 
-        SKGImportPluginOfx::m_ofxInitialBalance.clear();
+        SKGImportPluginOfx::m_ofxInitialBalanceName.clear();
+        SKGImportPluginOfx::m_ofxInitialBalanceAmount.clear();
+        SKGImportPluginOfx::m_ofxInitialBalanceDate.clear();
 
         SKGENDTRANSACTION(m_importer->getDocument(),  err);
     }
     return err;
 }
 
-SKGError SKGImportPluginOfx::getAccount(OfxAccountData* iAccountData, SKGDocumentBank* iDoc, SKGAccountObject& oAccount)
+QString SKGImportPluginOfx::getAccountName(OfxAccountData* iAccountData)
 {
-    SKGError err;
-    QString accountNumber = iAccountData->account_id;
-    QString bankNumber = iAccountData->bank_id;
-    // Correction BUG 234771 vvvvv
-    accountNumber = accountNumber.trimmed();
-    bankNumber = bankNumber.trimmed();
-    // Correction BUG 234771 ^^^^^
-    if (accountNumber.startsWith(bankNumber % ' ')) {
-        accountNumber = accountNumber.right(accountNumber.length() - bankNumber.length() - 1);
-        QStringList splitNumbers = accountNumber.split(' ');
-        if (splitNumbers.count() == 2) {
-            accountNumber = splitNumbers.at(1);
+    QString accountNumber;
+    if (iAccountData) {
+        accountNumber = iAccountData->account_id;
+        QString bankNumber = iAccountData->bank_id;
+        // Correction BUG 234771 vvvvv
+        accountNumber = accountNumber.trimmed();
+        bankNumber = bankNumber.trimmed();
+        // Correction BUG 234771 ^^^^^
+        if (accountNumber.startsWith(bankNumber % ' ')) {
+            accountNumber = accountNumber.right(accountNumber.length() - bankNumber.length() - 1);
+            QStringList splitNumbers = accountNumber.split(' ');
+            if (splitNumbers.count() == 2) {
+                accountNumber = splitNumbers.at(1);
+            }
         }
     }
 
-    // Check if account is already existing
-    err = iDoc->getObject("v_account", "t_number='" % accountNumber % '\'', oAccount);
+    return accountNumber;
+}
+
+SKGError SKGImportPluginOfx::getAccount(OfxAccountData* iAccountData, SKGDocumentBank* iDoc, SKGAccountObject& oAccount)
+{
+    SKGError err;
+    if (iAccountData && iDoc) {
+        // Check if account is already existing
+        err = iDoc->getObject("v_account", "t_number='" % SKGServices::stringToSqlString(getAccountName(iAccountData)) % '\'', oAccount);
+    }
 
     return err;
 }
@@ -183,7 +193,9 @@ int SKGImportPluginOfx::ofxStatementCallback(struct OfxStatementData data, void*
             if (act.getNbOperation() > 1) {
                 SKGImportPluginOfx::m_ofxError = doc->sendMessage(i18nc("An information message", "The initial balance of '%1' has not been set because some operations are already existing", act.getName()), SKGDocument::Warning);
             } else {
-                m_ofxInitialBalance.push_back(data);
+                m_ofxInitialBalanceName.push_back(getAccountName(accountData));
+                m_ofxInitialBalanceDate.push_back(data.ledger_balance_date_valid == true ? QDateTime::fromTime_t(data.ledger_balance_date).date() : QDate::currentDate());
+                m_ofxInitialBalanceAmount.push_back(data.ledger_balance);
             }
         }
     }
@@ -240,7 +252,7 @@ int SKGImportPluginOfx::ofxAccountCallback(struct OfxAccountData data, void* pv)
 
         // Check if bank is already existing
         SKGBankObject bank;
-        SKGImportPluginOfx::m_ofxError = doc->getObject("v_bank", "t_bank_number='" % bankId % '\'', tmp);
+        SKGImportPluginOfx::m_ofxError = doc->getObject("v_bank", "t_bank_number='" % SKGServices::stringToSqlString(bankId) % '\'', tmp);
         if (!SKGImportPluginOfx::m_ofxError) {
             // Already existing
             bank = tmp;
@@ -317,7 +329,7 @@ int SKGImportPluginOfx::ofxAccountCallback(struct OfxAccountData data, void* pv)
     if (data.currency_valid == true) {
         // Check if unit is already existing
         SKGUnitObject unit(doc);
-        SKGImportPluginOfx::m_ofxError = doc->getObject("v_unit", "t_name='" % QString::fromUtf8(data.currency) % "' OR t_name like '%(" % QString::fromUtf8(data.currency) % ")%'", tmp);
+        SKGImportPluginOfx::m_ofxError = doc->getObject("v_unit", "t_name='" % SKGServices::stringToSqlString(QString::fromUtf8(data.currency)) % "' OR t_name like '%(" % SKGServices::stringToSqlString(QString::fromUtf8(data.currency)) % ")%'", tmp);
         if (!SKGImportPluginOfx::m_ofxError) {
             // Already existing
             unit = tmp;
