@@ -70,8 +70,11 @@ private:
     static int ofxAccountCallback(struct OfxAccountData data, void* pv);
     static int ofxTransactionCallback(struct OfxTransactionData data, void* pv);
     static int ofxStatementCallback(struct OfxStatementData data, void* pv);
-    static QList<OfxStatementData> m_ofxInitialBalance;
+    static QStringList m_ofxInitialBalanceName;
+    static QList<double> m_ofxInitialBalanceAmount;
+    static QList<QDate> m_ofxInitialBalanceDate;
     static SKGError getAccount(OfxAccountData* iAccountData, SKGDocumentBank* iDoc, SKGAccountObject& oAccount);
+    static QString getAccountName(OfxAccountData* iAccountData);
 
     static SKGError m_ofxError;
 };
