@@ -55,7 +55,7 @@ public:
      * @return an object managing the error.
      *   @see SKGError
      */
-    virtual SKGError exportFile();
+    virtual SKGError exportFile() Q_DECL_OVERRIDE;
 
     /**
      * Return the mime type filter
