@@ -61,7 +61,7 @@ public:
     void reloadConfiguration() Q_DECL_OVERRIDE;
 
 protected Q_SLOTS:
-    void init();
+    void init() Q_DECL_OVERRIDE;
 
 private:
     QString m_triggerWord;
