@@ -46,7 +46,7 @@
 K_PLUGIN_FACTORY(SKGBankPluginFactory, registerPlugin<SKGBankPlugin>();)
 
 SKGBankPlugin::SKGBankPlugin(QWidget* iWidget, QObject* iParent, const QVariantList& /*iArg*/)
-    : SKGInterfacePlugin(iParent), m_currentBankDocument(NULL)
+    : SKGInterfacePlugin(iParent), m_currentBankDocument(NULL), m_reconciliateAction(NULL)
 {
     Q_UNUSED(iWidget);
     SKGTRACEINFUNC(10);
@@ -71,7 +71,7 @@ bool SKGBankPlugin::setupActions(SKGDocument* iDocument, const QStringList& iArg
     setXMLFile("skrooge_bank.rc");
 
     // Menu
-    QAction* actReconciliate = new QAction(QIcon::fromTheme("window-duplicate"), i18nc("Verb: Reconciliation is process through which you ensure compliance with your bank's statement", "Reconcile..."), this);
+    QAction* actReconciliate = new QAction(SKGServices::fromTheme("window-duplicate"), i18nc("Verb: Reconciliation is process through which you ensure compliance with your bank's statement", "Reconcile..."), this);
     connect(actReconciliate, &QAction::triggered, this, &SKGBankPlugin::onReconciliate);
     actionCollection()->setDefaultShortcut(actReconciliate, Qt::ALT + Qt::Key_R);
     registerGlobalAction("edit_reconciliate", actReconciliate, QStringList() << "account", 1, -1, 320);
