@@ -143,24 +143,24 @@ SKGBankPluginWidget::SKGBankPluginWidget(SKGDocumentBank* iDocument)
     connect(&m_timer, &QTimer::timeout, this, &SKGBankPluginWidget::refreshInfoZone, Qt::QueuedConnection);
 
     // Add Standard KDE Icons to buttons to Accounts
-    ui.kAccountCreatorUpdate->setIcon(QIcon::fromTheme("dialog-ok-apply"));
-    ui.kAccountCreatorAdd->setIcon(QIcon::fromTheme("list-add"));
+    ui.kAccountCreatorUpdate->setIcon(SKGServices::fromTheme("dialog-ok"));
+    ui.kAccountCreatorAdd->setIcon(SKGServices::fromTheme("list-add"));
 
     SKGWidgetSelector::SKGListQWidget list;
     list.push_back(ui.SKGEditionWidget);
     list.push_back(ui.SKGEditionButtonswidget);
-    ui.kWidgetSelector->addButton(QIcon::fromTheme("configure"), i18n("Edit"), i18n("Display the account edit panel"), list);
+    ui.kWidgetSelector->addButton(SKGServices::fromTheme("configure"), i18n("Edit"), i18n("Display the account edit panel"), list);
 
     // Add NLS values for type of account
     // C=current D=credit card P=passif (for objects) I=Investment O=other
-    ui.kAccountCreatorType->addItem(QIcon::fromTheme("view-bank-account-savings"), i18nc("Noun, a type of account", "Current"), SKGAccountObject::CURRENT);
-    ui.kAccountCreatorType->addItem(QIcon::fromTheme("view-credit-card-account"), i18nc("Noun, a type of account", "Credit card"), SKGAccountObject::CREDITCARD);
-    ui.kAccountCreatorType->addItem(QIcon::fromTheme("view-bank-account-savings"), i18nc("Noun, a type of account", "Saving"), SKGAccountObject::SAVING);
-    ui.kAccountCreatorType->addItem(QIcon::fromTheme("view-stock-account"), i18nc("Noun, a type of account", "Investment"), SKGAccountObject::INVESTMENT);
-    ui.kAccountCreatorType->addItem(QIcon::fromTheme("view-loan-asset"), i18nc("Noun, a type of account", "Assets"), SKGAccountObject::ASSETS);
-    ui.kAccountCreatorType->addItem(QIcon::fromTheme("view-loan-asset"), i18nc("Noun, a type of account", "Loan"), SKGAccountObject::LOAN);
-    ui.kAccountCreatorType->addItem(QIcon::fromTheme("view-loan-asset"), i18nc("Noun, a type of account", "Pension"), SKGAccountObject::PENSION);
-    ui.kAccountCreatorType->addItem(QIcon::fromTheme("kwalletmanager"), i18nc("Noun, a type of account", "Wallet"), SKGAccountObject::WALLET);
+    ui.kAccountCreatorType->addItem(SKGServices::fromTheme("view-bank-account-savings"), i18nc("Noun, a type of account", "Current"), SKGAccountObject::CURRENT);
+    ui.kAccountCreatorType->addItem(SKGServices::fromTheme("view-credit-card-account"), i18nc("Noun, a type of account", "Credit card"), SKGAccountObject::CREDITCARD);
+    ui.kAccountCreatorType->addItem(SKGServices::fromTheme("view-bank-account-savings"), i18nc("Noun, a type of account", "Saving"), SKGAccountObject::SAVING);
+    ui.kAccountCreatorType->addItem(SKGServices::fromTheme("view-stock-account"), i18nc("Noun, a type of account", "Investment"), SKGAccountObject::INVESTMENT);
+    ui.kAccountCreatorType->addItem(SKGServices::fromTheme("view-loan-asset"), i18nc("Noun, a type of account", "Assets"), SKGAccountObject::ASSETS);
+    ui.kAccountCreatorType->addItem(SKGServices::fromTheme("view-loan-asset"), i18nc("Noun, a type of account", "Loan"), SKGAccountObject::LOAN);
+    ui.kAccountCreatorType->addItem(SKGServices::fromTheme("view-loan-asset"), i18nc("Noun, a type of account", "Pension"), SKGAccountObject::PENSION);
+    ui.kAccountCreatorType->addItem(SKGServices::fromTheme("kwalletmanager"), i18nc("Noun, a type of account", "Wallet"), SKGAccountObject::WALLET);
     ui.kAccountCreatorType->addItem(i18nc("Noun, a type of account", "Other"), SKGAccountObject::OTHER);
 
     // Bind account creation view
@@ -198,7 +198,7 @@ SKGBankPluginWidget::SKGBankPluginWidget(SKGDocumentBank* iDocument)
                 }
             }
         }
-        ui.kAccountCreatorIcon->addItem(QIcon::fromTheme("document-open-folder"), i18nc("Other type of bank account", "Other..."));
+        ui.kAccountCreatorIcon->addItem(SKGServices::fromTheme("document-open-folder"), i18nc("Other type of bank account", "Other..."));
 
         file.close();
     }
