@@ -80,7 +80,7 @@ SKGBudgetPluginWidget::SKGBudgetPluginWidget(SKGDocument* iDocument)
                                        "all",    // Uncheck when unchecked
                                        Qt::META + Qt::Key_0);
     ui.kView->getShowWidget()->addSeparator();
-    ui.kView->getShowWidget()->addItem("current", i18nc("Noun, budget items to display", "Current"), "",
+    ui.kView->getShowWidget()->addItem("current", i18nc("Noun, budget items to display", "Current"), "view-calendar-whatsnext",
                                        "t_PERIOD>=STRFTIME('%Y-%m', date('now')) OR t_PERIOD=STRFTIME('%Y', date('now'))",
                                        "currentMonth",  // Check when checked
                                        "none",       // Uncheck when checked
@@ -117,7 +117,7 @@ SKGBudgetPluginWidget::SKGBudgetPluginWidget(SKGDocument* iDocument)
                                        "",
                                        "all",
                                        Qt::META + Qt::Key_4);
-    ui.kView->getShowWidget()->setDefaultState("current");
+    ui.kView->getShowWidget()->setDefaultState("current;currentMonth");
 
     m_timer.setSingleShot(true);
     connect(&m_timer, &QTimer::timeout, this, &SKGBudgetPluginWidget::refreshInfoZone, Qt::QueuedConnection);
@@ -147,8 +147,8 @@ SKGBudgetPluginWidget::SKGBudgetPluginWidget(SKGDocument* iDocument)
     connect(ui.kView->getView(), &SKGTreeView::selectionChangedDelayed, [ = ] {this->onSelectionChanged();});
 
     // Add Standard KDE Icons to buttons to Operations
-    ui.kModifyBtn->setIcon(QIcon::fromTheme("dialog-ok-apply"));
-    ui.kAddBtn->setIcon(QIcon::fromTheme("list-add"));
+    ui.kModifyBtn->setIcon(SKGServices::fromTheme("dialog-ok"));
+    ui.kAddBtn->setIcon(SKGServices::fromTheme("list-add"));
     QAction* processAction = SKGMainPanel::getMainPanel()->getGlobalAction("tool_process_budget_rules");
     if (processAction) {
         ui.kProcessBtn->setIcon(processAction->icon());
@@ -159,19 +159,19 @@ SKGBudgetPluginWidget::SKGBudgetPluginWidget(SKGDocument* iDocument)
         SKGWidgetSelector::SKGListQWidget list;
         list.push_back(ui.SKGManualSection);
         list.push_back(ui.SKGEditionButtonsSection);
-        ui.kWidgetSelector->addButton(QIcon::fromTheme("user-properties"), i18n("Manual"), i18n("Display the edit panel for standard budget"), list);
+        ui.kWidgetSelector->addButton(SKGServices::fromTheme("user-properties"), i18n("Manual"), i18n("Display the edit panel for standard budget"), list);
     }
     {
         SKGWidgetSelector::SKGListQWidget list;
         list.push_back(ui.SKGAutoSection);
         list.push_back(ui.SKGEditionButtonsSection);
-        ui.kWidgetSelector->addButton(QIcon::fromTheme("games-solve"), i18n("Auto"), i18n("Display the edit panel for automatic budgets"), list);
+        ui.kWidgetSelector->addButton(SKGServices::fromTheme("games-solve"), i18n("Auto"), i18n("Display the edit panel for automatic budgets"), list);
     }
     {
         SKGWidgetSelector::SKGListQWidget list;
         list.push_back(ui.SKGRuleSection);
         list.push_back(ui.SKGEditionButtonsSection);
-        ui.kWidgetSelector->addButton(QIcon::fromTheme("view-financial-transfer"), i18n("Rules"), i18n("Display the edit panel for rules"), list);
+        ui.kWidgetSelector->addButton(SKGServices::fromTheme("view-financial-transfer"), i18n("Rules"), i18n("Display the edit panel for rules"), list);
     }
     connect(ui.kWidgetSelector, &SKGWidgetSelector::selectedModeChanged, this, &SKGBudgetPluginWidget::onBtnModeClicked, Qt::QueuedConnection);
 
