@@ -51,16 +51,16 @@ SKGCalculatorPluginWidget::SKGCalculatorPluginWidget(SKGDocumentBank* iDocument)
     ui.kUnitEdit->setDocument(iDocument);
     ui.kUnitEdit->setWhereClauseCondition("t_type IN ('1','2','C')");
 
-    ui.kUpdate->setIcon(QIcon::fromTheme("dialog-ok-apply"));
-    ui.kAdd->setIcon(QIcon::fromTheme("list-add"));
+    ui.kUpdate->setIcon(SKGServices::fromTheme("dialog-ok"));
+    ui.kAdd->setIcon(SKGServices::fromTheme("list-add"));
 
-    ui.kLoadSummaryTitle->setPixmap(QIcon::fromTheme("configure").pixmap(22, 22), KTitleWidget::ImageLeft);
-    ui.kPaymentSummaryTitle->setPixmap(QIcon::fromTheme("bookmarks").pixmap(22, 22), KTitleWidget::ImageLeft);
-    ui.kAmortizationTableTitle->setPixmap(QIcon::fromTheme("view-pim-calendar").pixmap(22, 22), KTitleWidget::ImageLeft);
+    ui.kLoadSummaryTitle->setPixmap(SKGServices::fromTheme("configure").pixmap(22, 22), KTitleWidget::ImageLeft);
+    ui.kPaymentSummaryTitle->setPixmap(SKGServices::fromTheme("bookmarks").pixmap(22, 22), KTitleWidget::ImageLeft);
+    ui.kAmortizationTableTitle->setPixmap(SKGServices::fromTheme("view-pim-calendar").pixmap(22, 22), KTitleWidget::ImageLeft);
 
-    ui.kInterestResultsTitle->setPixmap(QIcon::fromTheme("bookmarks").pixmap(22, 22), KTitleWidget::ImageLeft);
-    ui.kInterestValuesTitle->setPixmap(QIcon::fromTheme("configure").pixmap(22, 22), KTitleWidget::ImageLeft);
-    ui.kDefineValueTitle->setPixmap(QIcon::fromTheme("configure").pixmap(22, 22), KTitleWidget::ImageLeft);
+    ui.kInterestResultsTitle->setPixmap(SKGServices::fromTheme("bookmarks").pixmap(22, 22), KTitleWidget::ImageLeft);
+    ui.kInterestValuesTitle->setPixmap(SKGServices::fromTheme("configure").pixmap(22, 22), KTitleWidget::ImageLeft);
+    ui.kDefineValueTitle->setPixmap(SKGServices::fromTheme("configure").pixmap(22, 22), KTitleWidget::ImageLeft);
 
     ui.kCreditValueDate->addItem(i18nc("A period of 15 days",  "Fifteen"));
     ui.kDebitValueDate->addItem(i18nc("A period of 15 days",  "Fifteen"));
@@ -78,8 +78,8 @@ SKGCalculatorPluginWidget::SKGCalculatorPluginWidget(SKGDocumentBank* iDocument)
     SKGWidgetSelector::SKGListQWidget list;
     list.push_back(ui.kInterestFrm);
     list.push_back(ui.kBtnFrm);
-    ui.kWidgetSelector->addButton(QIcon::fromTheme("taxes-finances"), i18n("Interest"), i18n("Interests calculator"), list);
-    ui.kWidgetSelector->addButton(QIcon::fromTheme("accessories-calculator"), i18n("Amortization Table"), i18n("Loan amortization table calculator"), ui.kAmortizationFrm);
+    ui.kWidgetSelector->addButton(SKGServices::fromTheme("taxes-finances"), i18n("Interest"), i18n("Interests calculator"), list);
+    ui.kWidgetSelector->addButton(SKGServices::fromTheme("accessories-calculator"), i18n("Amortization Table"), i18n("Loan amortization table calculator"), ui.kAmortizationFrm);
     connect(ui.kWidgetSelector, &SKGWidgetSelector::selectedModeChanged, this, &SKGCalculatorPluginWidget::onBtnModeClicked);
 
     // Bind account creation view
