@@ -103,7 +103,7 @@ bool SKGCategoriesPlugin::setupActions(SKGDocument* iDocument, const QStringList
     registerGlobalAction("clean_delete_unused_categories", deleteUnusedCategoriesAction);
 
     // ------------
-    QAction* actTmp = new QAction(QIcon::fromTheme(icon()), i18nc("Verb", "Open similar categories..."), this);
+    QAction* actTmp = new QAction(SKGServices::fromTheme(icon()), i18nc("Verb", "Open similar categories..."), this);
     actTmp->setData(QString("skg://skrooge_categories_plugin/?title_icon=" % icon() % "&title=" % SKGServices::encodeForUrl(i18nc("Noun, a list of items", "Similar categories")) %
                             "&whereClause=" % SKGServices::encodeForUrl("id IN (SELECT category.id FROM category, ("
                                     "SELECT * FROM category C WHERE EXISTS (SELECT 1 FROM category p2 WHERE p2.id<>C.id AND upper(p2.t_fullname)=upper(C.t_fullname) AND p2.t_fullname<>C.t_fullname)) "
