@@ -69,8 +69,8 @@ SKGCategoriesPluginWidget::SKGCategoriesPluginWidget(SKGDocumentBank* iDocument)
 
     ui.kNameLbl->setText(i18n("%1:", iDocument->getDisplay("t_name")));
 
-    ui.kModifyCategoryButton->setIcon(QIcon::fromTheme("dialog-ok-apply"));
-    ui.kDeleteUnusedButton->setIcon(QIcon::fromTheme("edit-delete"));
+    ui.kModifyCategoryButton->setIcon(SKGServices::fromTheme("dialog-ok"));
+    ui.kDeleteUnusedButton->setIcon(SKGServices::fromTheme("edit-delete"));
 
     ui.kCategoriesView->setModel(new SKGObjectModel(static_cast<SKGDocumentBank*>(getDocument()), "v_category_display", "1=0", this, "rd_category_id", false));
     ui.kCategoriesView->getView()->setRootIsDecorated(true);
@@ -206,7 +206,7 @@ void SKGCategoriesPluginWidget::setState(const QString& iState)
     doc.setContent(iState);
     QDomElement root = doc.documentElement();
 
-    ui.kCategoriesView->setFilter(QIcon::fromTheme(root.attribute("title_icon")), root.attribute("title"), root.attribute("whereClause"));
+    ui.kCategoriesView->setFilter(SKGServices::fromTheme(root.attribute("title_icon")), root.attribute("title"), root.attribute("whereClause"));
     ui.kCategoriesView->setState(root.attribute("view"));
 }
 
