@@ -75,7 +75,7 @@ bool SKGImportExportPlugin::setupActions(SKGDocument* iDocument, const QStringLi
     setXMLFile("skrooge_importexport.rc");
 
     // Imports
-    KActionMenu* imports = new  KActionMenu(QIcon::fromTheme("document-import"), i18nc("Verb, action to import items from another format", "Import"), this);
+    KActionMenu* imports = new  KActionMenu(SKGServices::fromTheme("document-import"), i18nc("Verb, action to import items from another format", "Import"), this);
     registerGlobalAction("import", imports);
 
     // Import
@@ -119,18 +119,18 @@ bool SKGImportExportPlugin::setupActions(SKGDocument* iDocument, const QStringLi
     registerGlobalAction("import_csv_rule", actImportCsvRule);
 
     // Exports
-    KActionMenu* exports = new  KActionMenu(QIcon::fromTheme("document-export"), i18nc("Verb, action to export items in another format", "Export"), this);
+    KActionMenu* exports = new  KActionMenu(SKGServices::fromTheme("document-export"), i18nc("Verb, action to export items in another format", "Export"), this);
     registerGlobalAction("export", exports);
 
     // Export
-    QAction* actExportFile = new QAction(QIcon::fromTheme("document-export"), i18nc("Verb, action to export items to another format", "Export..."), this);
+    QAction* actExportFile = new QAction(SKGServices::fromTheme("document-export"), i18nc("Verb, action to export items to another format", "Export..."), this);
     connect(actExportFile, &QAction::triggered, this, &SKGImportExportPlugin::exportFile);
     exports->addAction(actExportFile);
     actionCollection()->setDefaultShortcut(actExportFile, Qt::CTRL + Qt::META + Qt::Key_E);
     registerGlobalAction("export_operation", actExportFile);
 
     // Processing
-    KActionMenu* processing = new  KActionMenu(QIcon::fromTheme("tools-wizard"), i18nc("Noun, apply some kind of transformation on an item", "Processing"), this);
+    KActionMenu* processing = new  KActionMenu(SKGServices::fromTheme("tools-wizard"), i18nc("Noun, apply some kind of transformation on an item", "Processing"), this);
     registerGlobalAction("processing", processing);
 
     // Processing found and group
@@ -149,14 +149,14 @@ bool SKGImportExportPlugin::setupActions(SKGDocument* iDocument, const QStringLi
     registerGlobalAction("process_anonymize", actProcessingAnonymize);
 
     // Processing banks
-    QAction* actProcessingBank = new QAction(QIcon::fromTheme("tools-wizard"), i18nc("Verb, action to clean an import", "Clean bank's imports"), this);
+    QAction* actProcessingBank = new QAction(SKGServices::fromTheme("tools-wizard"), i18nc("Verb, action to clean an import", "Clean bank's imports"), this);
     connect(actProcessingBank, &QAction::triggered, this, &SKGImportExportPlugin::cleanBanks);
     processing->addAction(actProcessingBank);
     registerGlobalAction("process_banks", actProcessingBank);
 
     // Processing banks
     QStringList overlayValidate;
-    overlayValidate.push_back("dialog-ok-apply");
+    overlayValidate.push_back("dialog-ok");
     QAction* actValidateImportedOperations = new QAction(SKGServices::fromTheme("document-import", overlayValidate), i18nc("Verb, action to validate imported operations", "Validate imported operations"), this);
     connect(actValidateImportedOperations, &QAction::triggered, this, &SKGImportExportPlugin::validateImportedOperations);
     actionCollection()->setDefaultShortcut(actValidateImportedOperations, Qt::CTRL + Qt::SHIFT + Qt::Key_V);
@@ -179,13 +179,13 @@ bool SKGImportExportPlugin::setupActions(SKGDocument* iDocument, const QStringLi
     actionCollection()->setDefaultShortcut(actOpenNotValidated, Qt::META + Qt::Key_V);
     registerGlobalAction("view_open_not_validated", actOpenNotValidated);
 
-    QAction* actMergeImportedOperation = new QAction(QIcon::fromTheme("merge"), i18nc("Verb, action to merge", "Merge imported operations"), this);
+    QAction* actMergeImportedOperation = new QAction(SKGServices::fromTheme("merge"), i18nc("Verb, action to merge", "Merge imported operations"), this);
     connect(actMergeImportedOperation, &QAction::triggered, this, &SKGImportExportPlugin::mergeImportedOperation);
     actionCollection()->setDefaultShortcut(actMergeImportedOperation, Qt::CTRL + Qt::ALT + Qt::Key_M);
     registerGlobalAction("merge_imported_operation", actMergeImportedOperation, QStringList() << "operation", 1, -1, 319);
 
     QAction* force = new QAction(i18nc("Noun", "Force the merge"), this);
-    force->setIcon(QIcon::fromTheme("merge"));
+    force->setIcon(SKGServices::fromTheme("merge"));
     force->setData(1);
     connect(force, &QAction::triggered, this, &SKGImportExportPlugin::mergeImportedOperation);
     registerGlobalAction("merge_imported_operation_force", force);
@@ -355,7 +355,7 @@ SKGError SKGImportExportPlugin::importbackends()
         // Check if already in a transaction
         if (!m_currentBankDocument->checkExistingTransaction()) {
             // Repeat later
-            QTimer::singleShot(300, Qt::CoarseTimer, this, SLOT(importbackends()));
+            QTimer::singleShot(300, Qt::CoarseTimer, this, &SKGImportExportPlugin::importbackends);
             return err;
         }
 
@@ -588,7 +588,7 @@ void SKGImportExportPlugin::import(const QList<QUrl>& iFiles, int mode)
         if (err.getReturnCode() == ERR_INSTALL && msg) {
             QString application = err.property("application").toString();
             QAction* install = new QAction(i18nc("Noun", "Install %1", application), msg);
-            install->setIcon(QIcon::fromTheme("download"));
+            install->setIcon(SKGServices::fromTheme("download"));
             msg->addAction(install);
             connect(install, &QAction::triggered, this, &SKGImportExportPlugin::onInstall);
             connect(install, &QAction::triggered, msg, &KMessageWidget::deleteLater, Qt::QueuedConnection);
@@ -876,7 +876,7 @@ SKGAdviceList SKGImportExportPlugin::advice(const QStringList& iIgnoredAdvice)
             QFile file(fileName);
             if (file.open(QIODevice::ReadOnly | QIODevice::Text)) {
                 QTextStream stream(&file);
-                stream.readLine().trimmed();  // action not used yet
+                stream.readLine();  // action not used yet
                 QString date = QLocale().toString(SKGServices::stringToTime(stream.readLine().trimmed()).date(), QLocale::ShortFormat);
                 QString amount = m_currentBankDocument->formatMoney(SKGServices::stringToDouble(stream.readLine().trimmed()), m_currentBankDocument->getPrimaryUnit());
                 QString payee = stream.readLine().trimmed();
@@ -929,7 +929,7 @@ SKGError SKGImportExportPlugin::executeAdviceCorrection(const QString& iAdviceId
                 err = SKGError(ERR_FAIL, i18nc("An erro message", "Open file '%1' failed", fileName));
             } else {
                 QTextStream stream(&file);
-                stream.readLine().trimmed();  // action is not used yet
+                stream.readLine();  // action is not used yet
                 QDate date = SKGServices::stringToTime(stream.readLine().trimmed()).date();
                 double amount = SKGServices::stringToDouble(stream.readLine().trimmed());
                 QString payee = stream.readLine().trimmed();
