@@ -147,18 +147,6 @@ private:
     Q_DISABLE_COPY(SKGImportExportPlugin)
     void openLastModifiedIfSetting();
 
-    QAction* m_importAction;
-    QAction* m_importBackendAction;
-    QAction* m_importCsvUnitAction;
-    QAction* m_importCsvRuleAction;
-    QAction* m_exportFileAction;
-    QAction* m_processingFoundTransfert;
-    QAction* m_processingBank;
-    QAction* m_processingAnonymize;
-    QAction* m_validateImportedOperationsAction;
-    QAction* m_openNotValidatedAction;
-    QAction* m_mergeImportedOperationAction;
-
     SKGDocumentBank* m_currentBankDocument;
 
     QString m_docUniqueIdentifier;
