@@ -375,7 +375,9 @@ void SKGOperationBoardWidget::dataModified(const QString& iTableName, int iIdTra
                     m_anim->addAnimation(panim);
                 }
 
-                QTimer::singleShot(1000, Qt::CoarseTimer, m_anim, SLOT(start()));
+                QTimer::singleShot(1000, Qt::CoarseTimer, m_anim, [ = ]() {
+                    m_anim->start();
+                });
             }
 
             // No widget if no account
