@@ -88,25 +88,25 @@ bool SKGOperationPlugin::setupActions(SKGDocument* iDocument, const QStringList&
 
     // Menu
     // ------------
-    QAction* actDuplicateAction = new QAction(QIcon::fromTheme("window-duplicate"), i18nc("Verb, duplicate an object",  "Duplicate"), this);
+    QAction* actDuplicateAction = new QAction(SKGServices::fromTheme("window-duplicate"), i18nc("Verb, duplicate an object",  "Duplicate"), this);
     connect(actDuplicateAction, &QAction::triggered, this, &SKGOperationPlugin::onDuplicate);
     actionCollection()->setDefaultShortcut(actDuplicateAction, Qt::CTRL + Qt::Key_D);
     registerGlobalAction("edit_duplicate_operation", actDuplicateAction, listOperation, 1, -1, 400);
 
     // ------------
-    QAction* actCreateTemplateAction = new QAction(QIcon::fromTheme("edit-guides"), i18nc("Verb", "Create template"), this);
+    QAction* actCreateTemplateAction = new QAction(SKGServices::fromTheme("edit-guides"), i18nc("Verb", "Create template"), this);
     connect(actCreateTemplateAction, &QAction::triggered, this, &SKGOperationPlugin::onCreateTemplate);
     actionCollection()->setDefaultShortcut(actCreateTemplateAction, Qt::CTRL + Qt::SHIFT + Qt::Key_T);
     registerGlobalAction("edit_template_operation", actCreateTemplateAction, listOperation, 1, -1, 401);
 
     // ------------
-    QAction*  actSwitchToPointedAction = new QAction(QIcon::fromTheme("dialog-ok"), i18nc("Verb, mark an object", "Point"), this);
+    QAction*  actSwitchToPointedAction = new QAction(SKGServices::fromTheme("dialog-ok"), i18nc("Verb, mark an object", "Point"), this);
     connect(actSwitchToPointedAction, &QAction::triggered, this, &SKGOperationPlugin::onSwitchToPointed);
     actionCollection()->setDefaultShortcut(actSwitchToPointedAction, Qt::CTRL + Qt::Key_R);
     registerGlobalAction("edit_point_selected_operation", actSwitchToPointedAction, listOperation, 1, -1, 310);
 
     // ------------
-    QAction* actFastEdition = new QAction(QIcon::fromTheme("games-solve"), i18nc("Verb", "Fast edit"), this);
+    QAction* actFastEdition = new QAction(SKGServices::fromTheme("games-solve"), i18nc("Verb", "Fast edit"), this);
     actFastEdition->setEnabled(false);
     actionCollection()->setDefaultShortcut(actFastEdition, Qt::Key_F10);
     registerGlobalAction("fast_edition", actFastEdition, listOperation);
@@ -263,7 +263,7 @@ bool SKGOperationPlugin::setupActions(SKGDocument* iDocument, const QStringList&
     registerGlobalAction("clean_remove_group_with_one_operation", actCleanRemoveGroupWithOneOperation);
 
     // ------------
-    QAction* actGroupOperation = new QAction(QIcon::fromTheme("view-financial-transfer"), i18nc("Verb", "Group operations"), this);
+    QAction* actGroupOperation = new QAction(SKGServices::fromTheme("view-financial-transfer"), i18nc("Verb", "Group operations"), this);
     connect(actGroupOperation, &QAction::triggered, this, &SKGOperationPlugin::onGroupOperation);
     actionCollection()->setDefaultShortcut(actGroupOperation, Qt::CTRL + Qt::Key_G);
     registerGlobalAction("edit_group_operation", actGroupOperation, listOperation, 2, -1, 311);
@@ -277,12 +277,12 @@ bool SKGOperationPlugin::setupActions(SKGDocument* iDocument, const QStringList&
     registerGlobalAction("edit_ungroup_operation", actUngroupOperation, listOperation, 1, -1, 312);
 
     // ------------
-    QAction* actMergeOperationAction = new QAction(QIcon::fromTheme("split"), i18nc("Verb, action to merge", "Merge sub operations"), this);
+    QAction* actMergeOperationAction = new QAction(SKGServices::fromTheme("split"), i18nc("Verb, action to merge", "Merge sub operations"), this);
     connect(actMergeOperationAction, &QAction::triggered, this, &SKGOperationPlugin::onMergeSubOperations);
     actionCollection()->setDefaultShortcut(actMergeOperationAction, Qt::CTRL + Qt::SHIFT + Qt::Key_M);
     registerGlobalAction("merge_sub_operations", actMergeOperationAction, listOperation, 1, -1, 320);
 
-    KToolBarPopupAction* actApplyTemplateAction = new KToolBarPopupAction(QIcon::fromTheme("edit-guides"), i18nc("Verb, action to apply a template", "Apply template"), this);
+    KToolBarPopupAction* actApplyTemplateAction = new KToolBarPopupAction(SKGServices::fromTheme("edit-guides"), i18nc("Verb, action to apply a template", "Apply template"), this);
     m_applyTemplateMenu = static_cast<QMenu*>(actApplyTemplateAction->menu());
     connect(m_applyTemplateMenu, &QMenu::aboutToShow, this, &SKGOperationPlugin::onShowApplyTemplateMenu);
     actApplyTemplateAction->setStickyMenu(false);
@@ -324,7 +324,7 @@ void SKGOperationPlugin::onShowApplyTemplateMenu()
             fav = (listTmp.at(i).at(2) == "Y");
 
             // Add actions
-            QAction* act = m->addAction(QIcon::fromTheme("edit-guides"), listTmp.at(i).at(0));
+            QAction* act = m->addAction(SKGServices::fromTheme("edit-guides"), listTmp.at(i).at(0));
             if (act) {
                 act->setData(listTmp.at(i).at(1));
                 connect(act, &QAction::triggered, this, &SKGOperationPlugin::onApplyTemplate);
@@ -901,7 +901,7 @@ void SKGOperationPlugin::onOpenOperations()
                     SKGOperationObject op;
                     tmp.getParentOperation(op);
                     if (i) {
-                        wc += ',';
+                        wc += " OR ";
                         titleOpen += ',';
                     }
 
