@@ -71,7 +71,7 @@ bool SKGPayeePlugin::setupActions(SKGDocument* iDocument, const QStringList& iAr
     registerGlobalAction("clean_delete_unused_payees", deleteUnusedPayeesAction);
 
     // ------------
-    QAction* actTmp = new QAction(QIcon::fromTheme(icon()), i18nc("Verb", "Open similar payees..."), this);
+    QAction* actTmp = new QAction(SKGServices::fromTheme(icon()), i18nc("Verb", "Open similar payees..."), this);
     actTmp->setData(QString("skg://skrooge_payee_plugin/?title_icon=" % icon() % "&title=" % SKGServices::encodeForUrl(i18nc("Noun, a list of items", "Similar payees")) %
                             "&whereClause=" % SKGServices::encodeForUrl("EXISTS (SELECT 1 FROM payee p2 WHERE p2.id<>v_payee_display.id AND upper(p2.t_name)=upper(v_payee_display.t_name) AND p2.t_name<>v_payee_display.t_name)")));
     connect(actTmp, &QAction::triggered, SKGMainPanel::getMainPanel(), [ = ]() {
