@@ -53,9 +53,9 @@ SKGPayeePluginWidget::SKGPayeePluginWidget(SKGDocument* iDocument)
     ui.kNameLbl->setText(i18n("%1:", iDocument->getDisplay("t_name")));
     ui.kAddressLabel->setText(i18n("%1:", iDocument->getDisplay("t_address")));
 
-    ui.kAddButton->setIcon(QIcon::fromTheme("list-add"));
-    ui.kModifyButton->setIcon(QIcon::fromTheme("dialog-ok-apply"));
-    ui.kDeleteUnusedButton->setIcon(QIcon::fromTheme("edit-delete"));
+    ui.kAddButton->setIcon(SKGServices::fromTheme("list-add"));
+    ui.kModifyButton->setIcon(SKGServices::fromTheme("dialog-ok"));
+    ui.kDeleteUnusedButton->setIcon(SKGServices::fromTheme("edit-delete"));
 
     ui.kView->setModel(new SKGObjectModel(static_cast<SKGDocumentBank*>(getDocument()), "v_payee_display", "1=0", this, "", false));
     ui.kView->getView()->resizeColumnToContents(0);
@@ -128,7 +128,7 @@ void SKGPayeePluginWidget::setState(const QString& iState)
     doc.setContent(iState);
     QDomElement root = doc.documentElement();
 
-    ui.kView->setFilter(QIcon::fromTheme(root.attribute("title_icon")), root.attribute("title"), root.attribute("whereClause"));
+    ui.kView->setFilter(SKGServices::fromTheme(root.attribute("title_icon")), root.attribute("title"), root.attribute("whereClause"));
     ui.kView->setState(root.attribute("view"));
 }
 
