@@ -24,7 +24,6 @@
 #include "skginterfaceplugin.h"
 #include "ui_skgreportpluginwidget_pref.h"
 
-class QAction;
 class SKGDocumentBank;
 
 /**
@@ -86,11 +85,6 @@ public:
      */
     virtual KConfigSkeleton* getPreferenceSkeleton() Q_DECL_OVERRIDE;
 
-    /**
-     * Must be modified to refresh widgets after a modification.
-     */
-    virtual void refresh() Q_DECL_OVERRIDE;
-
     /**
      * The page widget of the plugin.
      * @return The page widget of the plugin
@@ -154,7 +148,6 @@ private Q_SLOTS:
 private:
     Q_DISABLE_COPY(SKGReportPlugin)
 
-    QAction* m_openReportAction;
     SKGDocumentBank* m_currentBankDocument;
 
     Ui::skgreportplugin_pref ui;
