@@ -63,33 +63,33 @@ SKGReportPluginWidget::SKGReportPluginWidget(SKGDocumentBank* iDocument, bool iM
 
     ui.kLineLabel->setText("");
 
-    ui.kLineUp->setIcon(QIcon::fromTheme("list-add"));
-    ui.kLineDown->setIcon(QIcon::fromTheme("list-remove"));
-    ui.kColUp->setIcon(QIcon::fromTheme("list-add"));
-    ui.kColDown->setIcon(QIcon::fromTheme("list-remove"));
+    ui.kLineUp->setIcon(SKGServices::fromTheme("list-add"));
+    ui.kLineDown->setIcon(SKGServices::fromTheme("list-remove"));
+    ui.kColUp->setIcon(SKGServices::fromTheme("list-add"));
+    ui.kColDown->setIcon(SKGServices::fromTheme("list-remove"));
 
-    ui.kLineAdd->setIcon(QIcon::fromTheme("arrow-right"));
-    ui.kLineRemove->setIcon(QIcon::fromTheme("edit-delete"));
+    ui.kLineAdd->setIcon(SKGServices::fromTheme("arrow-right"));
+    ui.kLineRemove->setIcon(SKGServices::fromTheme("edit-delete"));
 
     // FIXME: Icons are not related to the text...
-    ui.kMode->addItem(QIcon::fromTheme("office-chart-pie"), i18nc("Display graph values as the sum of operations amount", "Sum of operations"), 0);
-    ui.kMode->addItem(QIcon::fromTheme("office-chart-line"), i18nc("Display graph values as the cumulated sum of operations amount", "Cumulated sum of operations"), 1);
-    ui.kMode->addItem(QIcon::fromTheme("office-chart-area-percentage"), i18nc("Display graph values in base 100", "Base 100"), 7);
-    ui.kMode->addItem(QIcon::fromTheme("office-chart-area-percentage"), i18nc("Display graph values in base 100", "Cumulated sum in base 100"), 8);
-    ui.kMode->addItem(QIcon::fromTheme("office-chart-area-percentage"), i18nc("Display graph values in percentage", "Percent of columns"), 2);
-    ui.kMode->addItem(QIcon::fromTheme("office-chart-area-percentage"), i18nc("Display graph values in percentage", "Absolute percent of columns"), 5);
-    ui.kMode->addItem(QIcon::fromTheme("office-chart-area-percentage"), i18nc("Display graph values in percentage", "Percent of lines"), 4);
-    ui.kMode->addItem(QIcon::fromTheme("office-chart-area-percentage"), i18nc("Display graph values in percentage", "Absolute percent of lines"), 6);
-    ui.kMode->addItem(QIcon::fromTheme("milestone"), i18nc("Display graph values as a number of operations (or transaction)", "Count number of operations"), 3);
+    ui.kMode->addItem(SKGServices::fromTheme("office-chart-pie"), i18nc("Display graph values as the sum of operations amount", "Sum of operations"), 0);
+    ui.kMode->addItem(SKGServices::fromTheme("office-chart-line"), i18nc("Display graph values as the cumulated sum of operations amount", "Cumulated sum of operations"), 1);
+    ui.kMode->addItem(SKGServices::fromTheme("office-chart-area-percentage"), i18nc("Display graph values in base 100", "Base 100"), 7);
+    ui.kMode->addItem(SKGServices::fromTheme("office-chart-area-percentage"), i18nc("Display graph values in base 100", "Cumulated sum in base 100"), 8);
+    ui.kMode->addItem(SKGServices::fromTheme("office-chart-area-percentage"), i18nc("Display graph values in percentage", "Percent of columns"), 2);
+    ui.kMode->addItem(SKGServices::fromTheme("office-chart-area-percentage"), i18nc("Display graph values in percentage", "Absolute percent of columns"), 5);
+    ui.kMode->addItem(SKGServices::fromTheme("office-chart-area-percentage"), i18nc("Display graph values in percentage", "Percent of lines"), 4);
+    ui.kMode->addItem(SKGServices::fromTheme("office-chart-area-percentage"), i18nc("Display graph values in percentage", "Absolute percent of lines"), 6);
+    ui.kMode->addItem(SKGServices::fromTheme("milestone"), i18nc("Display graph values as a number of operations (or transaction)", "Count number of operations"), 3);
 
     ui.kForecastCmb->addItem(i18nc("Noun", "None"), 0);
-    ui.kForecastCmb->addItem(QIcon::fromTheme("view-financial-forecast"), i18nc("Noun", "Moving average"), 2);
-    ui.kForecastCmb->addItem(QIcon::fromTheme("view-financial-forecast"), i18nc("Noun", "Weighted moving average"), 3);
-    // TODO(Stephane MANKOWSKI): ui.kForecastCmb->addItem(QIcon::fromTheme("applications-education-mathematics"), i18nc("Noun", "Interest rate") , 5);
-    ui.kForecastCmb->addItem(QIcon::fromTheme("chronometer"), i18nc("Noun", "Schedule"), 1);
-    ui.kForecastCmb->addItem(QIcon::fromTheme("view-calendar-whatsnext"), i18nc("Noun", "Budget"), 4);
+    ui.kForecastCmb->addItem(SKGServices::fromTheme("view-financial-forecast"), i18nc("Noun", "Moving average"), 2);
+    ui.kForecastCmb->addItem(SKGServices::fromTheme("view-financial-forecast"), i18nc("Noun", "Weighted moving average"), 3);
+    // TODO(Stephane MANKOWSKI): ui.kForecastCmb->addItem(SKGServices::fromTheme("applications-education-mathematics"), i18nc("Noun", "Interest rate") , 5);
+    ui.kForecastCmb->addItem(SKGServices::fromTheme("chronometer"), i18nc("Noun", "Schedule"), 1);
+    ui.kForecastCmb->addItem(SKGServices::fromTheme("view-calendar-whatsnext"), i18nc("Noun", "Budget"), 4);
 
-    ui.kWidgetSelector->addButton(QIcon::fromTheme("configure"), i18n("Setup Report"), i18n("Display the edit panel for report"), ui.setupWidget);
+    ui.kWidgetSelector->addButton(SKGServices::fromTheme("configure"), i18n("Setup Report"), i18n("Display the edit panel for report"), ui.setupWidget);
     connect(ui.kWidgetSelector, &SKGWidgetSelector::selectedModeChanged, this, &SKGReportPluginWidget::onBtnModeClicked);
 
     // Set colors
@@ -102,7 +102,7 @@ SKGReportPluginWidget::SKGReportPluginWidget(SKGDocumentBank* iDocument, bool iM
     QMenu* tableMenu = ui.kTableWithGraph->getTableContextualMenu();
     if (tableMenu) {
         tableMenu->addSeparator();
-        m_openAction = tableMenu->addAction(QIcon::fromTheme("quickopen"), i18nc("Verb", "Open..."));
+        m_openAction = tableMenu->addAction(SKGServices::fromTheme("quickopen"), i18nc("Verb", "Open..."));
         if (m_openAction) {
             m_openAction->setEnabled(false);
         }
@@ -408,7 +408,7 @@ void SKGReportPluginWidget::setState(const QString& iState)
 
     if (!title.isEmpty() && !wc.isEmpty()) {
         // Add new filter
-        QListWidgetItem* item = new QListWidgetItem(QIcon::fromTheme(title_icon), title);
+        QListWidgetItem* item = new QListWidgetItem(SKGServices::fromTheme(title_icon), title);
         item->setCheckState(Qt::Checked);
         item->setFlags(Qt::ItemIsUserCheckable | Qt::ItemIsEnabled);
         item->setData(1000, wc);
@@ -459,7 +459,7 @@ void SKGReportPluginWidget::getWhereClauseAndTitleForItem(int row, int column, Q
     }
 
     // Condition on line attribute
-    oTitle += i18nc("Noun, a list of items", "Sub operations with ");
+    oTitle += i18nc("Noun, a list of items", "Sub operations");
     SKGColorButton* btn = qobject_cast<SKGColorButton*>(ui.kTableWithGraph->table()->cellWidget(row, 0));
 
     QString attLine;
@@ -489,11 +489,13 @@ void SKGReportPluginWidget::getWhereClauseAndTitleForItem(int row, int column, Q
     oWc = attLine;
     QString lineVal = (btn ? btn->text() : ui.kTableWithGraph->table()->item(row, 0)->data(1).toString());
     QString title = ui.kTableWithGraph->table()->horizontalHeaderItem(0)->text();
+    bool avoidAnd = false;
     if (lineVal.isEmpty() && row == ui.kTableWithGraph->table()->rowCount() - 1) {
         // This is the last sum
         oWc = "";
         if (!attLine.isEmpty()) {
             oWc = attLine % " NOT LIKE '%#NULL#%'";
+            avoidAnd = true;
         }
     } else {
         // This is not the last sum
@@ -503,6 +505,7 @@ void SKGReportPluginWidget::getWhereClauseAndTitleForItem(int row, int column, Q
         oWc += " = '" % SKGServices::stringToSqlString(lineVal) % "' OR " %
                attLine % " like '" % SKGServices::stringToSqlString(lineVal) % OBJECTSEPARATOR % "%'";
         oWc = '(' % oWc % ')';
+        oTitle += i18nc("Noun",  " with ");
         oTitle += i18nc("Noun",  "'%1' with '%2'", title, lineVal);
     }
 
@@ -519,7 +522,13 @@ void SKGReportPluginWidget::getWhereClauseAndTitleForItem(int row, int column, Q
         if (column != 0 && column < nbCol) {
             if (!oWc.isEmpty()) {
                 oWc += " AND ";
-                oTitle += i18nc("Noun",  " and ");
+                if (!avoidAnd) {
+                    oTitle += i18nc("Noun",  " and ");
+                } else {
+                    oTitle += i18nc("Noun",  " with ");
+                }
+            } else {
+                oTitle += i18nc("Noun",  " with ");
             }
 
             oWc += '(' % att;
@@ -832,7 +841,7 @@ void SKGReportPluginWidget::pageChanged()
                 // Add it if not existing
                 if (!existing) {
                     QString icon = SKGMainPanel::getMainPanel()->getPluginByName(page->objectName())->icon();
-                    QListWidgetItem* item = new QListWidgetItem(QIcon::fromTheme(icon), title);
+                    QListWidgetItem* item = new QListWidgetItem(SKGServices::fromTheme(icon), title);
                     item->setFlags(Qt::ItemIsUserCheckable | Qt::ItemIsEnabled);
                     item->setCheckState(Qt::Unchecked);
                     item->setData(1000, wc);
