@@ -103,6 +103,7 @@ public Q_SLOTS:
 private Q_SLOTS:
     void pageChanged();
     void onDoubleClick(int row, int column);
+    void onOpen();
     void onOpenReport();
     void onSelectionChanged();
     void onOneLevelMore();
@@ -117,7 +118,8 @@ private:
     Q_DISABLE_COPY(SKGReportPluginWidget)
 
     QString getConsolidatedWhereClause(QString* oWhereClausForPreviousData = NULL, QString*  oWhereClausForForecastData = NULL);
-    void getWhereClauseAndTitleForSelection(int row, int column, QString& oWc, QString& oTitle);
+    void getWhereClauseAndTitleForItem(int row, int column, QString& oWc, QString& oTitle);
+    void getWhereClauseAndTitleForSelection(QString& oWc, QString& oTitle);
     QString getWhereClauseForProperty(const QString& iProperty) const;
 
     Ui::skgreportplugin_base ui;
@@ -126,6 +128,7 @@ private:
     QStringList m_attsForLines;
     QStringList m_attsForLinesAdded;
     QAction* m_openReportAction;
+    QAction* m_openAction;
     QTimer m_timer;
     int m_mode;
     int m_nbLevelLines;
