@@ -68,7 +68,7 @@ bool SKGScheduledPlugin::setupActions(SKGDocument* iDocument, const QStringList&
     setXMLFile("skrooge_scheduled.rc");
 
     // Create yours actions here
-    QAction* actScheduleOperation = new QAction(QIcon::fromTheme(icon()), i18nc("Verb, create a scheduled operation", "Schedule"), this);
+    QAction* actScheduleOperation = new QAction(SKGServices::fromTheme(icon()), i18nc("Verb, create a scheduled operation", "Schedule"), this);
     connect(actScheduleOperation, &QAction::triggered, this, &SKGScheduledPlugin::onScheduleOperation);
     actionCollection()->setDefaultShortcut(actScheduleOperation, Qt::CTRL + Qt::Key_I);
     registerGlobalAction("schedule_operation", actScheduleOperation, QStringList() << "operation", 1, -1, 410);
