@@ -47,7 +47,7 @@ SKGScheduledPluginWidget::SKGScheduledPluginWidget(SKGDocumentBank* iDocument)
 
     // Define action
     if (SKGMainPanel::getMainPanel()) {
-        QAction* actJumpToOperation = new QAction(QIcon::fromTheme("quickopen"), ui.kJumpBtn->text(), this);
+        QAction* actJumpToOperation = new QAction(SKGServices::fromTheme("quickopen"), ui.kJumpBtn->text(), this);
         connect(actJumpToOperation, &QAction::triggered, this, &SKGScheduledPluginWidget::onJumpToTheOperation);
         SKGMainPanel::getMainPanel()->registerGlobalAction("edit_reconciliate", actJumpToOperation, true, QStringList() << "recurrentoperation", 1, -1, 160);
     }
@@ -64,19 +64,19 @@ SKGScheduledPluginWidget::SKGScheduledPluginWidget(SKGDocumentBank* iDocument)
     connect(ui.kView->getView(), &SKGTreeView::selectionChangedDelayed, [ = ] {this->onSelectionChanged();});
 
     // Add Standard KDE Icons to buttons to Operations
-    ui.kModifyBtn->setIcon(QIcon::fromTheme("dialog-ok-apply"));
-    ui.kProcessBtn->setIcon(QIcon::fromTheme("system-run"));
+    ui.kModifyBtn->setIcon(SKGServices::fromTheme("dialog-ok"));
+    ui.kProcessBtn->setIcon(SKGServices::fromTheme("system-run"));
     connect(ui.kProcessBtn, &QToolButton::clicked, this, &SKGScheduledPluginWidget::onProcess);
 
-    QAction* processImmediatelyAction = new QAction(QIcon::fromTheme("system-run"), i18nc("User action", "Process immediately"), this);
+    QAction* processImmediatelyAction = new QAction(SKGServices::fromTheme("system-run"), i18nc("User action", "Process immediately"), this);
     connect(processImmediatelyAction, &QAction::triggered, this, &SKGScheduledPluginWidget::onProcessImmediately);
     QMenu* processMenu = new QMenu();
     processMenu->addAction(processImmediatelyAction);
     ui.kProcessBtn->setMenu(processMenu);
 
-    ui.kJumpBtn->setIcon(QIcon::fromTheme("quickopen"));
+    ui.kJumpBtn->setIcon(SKGServices::fromTheme("quickopen"));
 
-    ui.kTitle->setPixmap(QIcon::fromTheme("dialog-information").pixmap(22, 22), KTitleWidget::ImageLeft);
+    ui.kTitle->setPixmap(SKGServices::fromTheme("dialog-information").pixmap(22, 22), KTitleWidget::ImageLeft);
     bool exist = false;
     getDocument()->existObjects("recurrentoperation", "", exist);
     ui.kTitle->setVisible(!exist);
