@@ -79,7 +79,7 @@ protected:
      * @param iEvent event
      * @return In your reimplementation of this function, if you want to filter the event out, i.e. stop it being handled further, return true; otherwise return false.
      */
-    virtual bool eventFilter(QObject* iObject, QEvent* iEvent);
+    virtual bool eventFilter(QObject* iObject, QEvent* iEvent) Q_DECL_OVERRIDE;
 
 private Q_SLOTS:
     void onSelectionChanged();
