@@ -49,14 +49,14 @@ SKGAlarmBoardWidget::SKGAlarmBoardWidget(SKGDocument* iDocument)
     // Create menu
     setContextMenuPolicy(Qt::ActionsContextMenu);
 
-    QAction* open = new QAction(QIcon::fromTheme("quickopen"), i18nc("Verb, open a page", "Open..."), this);
+    QAction* open = new QAction(SKGServices::fromTheme("quickopen"), i18nc("Verb, open a page", "Open..."), this);
     open->setData("skg://skrooge_search_plugin");
     connect(open, &QAction::triggered, SKGMainPanel::getMainPanel(), [ = ]() {
         SKGMainPanel::getMainPanel()->SKGMainPanel::openPage();
     });
     addAction(open);
 
-    m_menuFavorite = new QAction(QIcon::fromTheme("bookmarks"), i18nc("Noun, an option in contextual menu", "Highlighted only"), this);
+    m_menuFavorite = new QAction(SKGServices::fromTheme("bookmarks"), i18nc("Noun, an option in contextual menu", "Highlighted only"), this);
     m_menuFavorite->setCheckable(true);
     m_menuFavorite->setChecked(false);
     connect(m_menuFavorite, &QAction::triggered, [ = ]() {
@@ -147,7 +147,7 @@ void SKGAlarmBoardWidget::dataModified(const QString& iTableName, int iIdTransac
                     progressBar->setSizePolicy(newSizePolicy);
 
                     // Set tooltip
-                    QString msg = alarm.Message.arg(doc->formatMoney(alarm.Amount, primary, false)).arg(doc->formatMoney(alarm.Limit, primary, false)).arg(doc->formatMoney(alarm.Amount - alarm.Limit, primary, false));
+                    QString msg = alarm.Message.arg(doc->formatMoney(alarm.Amount, primary, false), doc->formatMoney(alarm.Limit, primary, false), doc->formatMoney(alarm.Amount - alarm.Limit, primary, false));
                     QString txt = msg % "<br>";
                     txt += doc->formatMoney(alarm.Amount, primary, false) % " / " % doc->formatMoney(alarm.Limit, primary, false);
                     if (!secondary.Symbol.isEmpty() && secondary.Value) {
