@@ -89,7 +89,7 @@ bool SKGSearchPlugin::setupActions(SKGDocument* iDocument, const QStringList& iA
 
     // Create yours actions here
     // Execute on all operation
-    QAction* actExecuteAll = new QAction(QIcon::fromTheme("system-run"), i18nc("Verb, action to execute", "Execute on all operations"), this);
+    QAction* actExecuteAll = new QAction(SKGServices::fromTheme("system-run"), i18nc("Verb, action to execute", "Execute on all operations"), this);
     connect(actExecuteAll, &QAction::triggered, this, [ = ] { execute(SKGRuleObject::ALL); });
     registerGlobalAction("execute_all", actExecuteAll, QStringList() << "rule", 1, -1, 501);
 
@@ -105,7 +105,7 @@ bool SKGSearchPlugin::setupActions(SKGDocument* iDocument, const QStringList& iA
     // Execute on not validated
     {
         QStringList overlaycsv;
-        overlaycsv.push_back("dialog-ok-apply");
+        overlaycsv.push_back("dialog-ok");
         QAction* actExecuteNotValidated = new QAction(SKGServices::fromTheme("system-run", overlaycsv), i18nc("Verb, action to execute", "Execute on not validated operations"), this);
         connect(actExecuteNotValidated, &QAction::triggered, this, [ = ] { execute(SKGRuleObject::IMPORTEDNOTVALIDATE); });
         registerGlobalAction("execute_not_validated", actExecuteNotValidated, QStringList() << "rule", 1, -1, 503);
@@ -369,7 +369,7 @@ SKGAdviceList SKGSearchPlugin::advice(const QStringList& iIgnoredAdvice)
                         SKGAdvice ad;
                         ad.setUUID("skgsearchplugin_alarm|" % SKGServices::intToString(rule.getID()));
                         ad.setPriority(percent >= 90 ? 9 : 6);
-                        QString msg = alarm.Message.arg(m_currentBankDocument->formatMoney(alarm.Amount, primary, false)).arg(m_currentBankDocument->formatMoney(alarm.Limit, primary, false)).arg(m_currentBankDocument->formatMoney(alarm.Amount - alarm.Limit, primary, false));
+                        QString msg = alarm.Message.arg(m_currentBankDocument->formatMoney(alarm.Amount, primary, false), m_currentBankDocument->formatMoney(alarm.Limit, primary, false), m_currentBankDocument->formatMoney(alarm.Amount - alarm.Limit, primary, false));
                         ad.setShortMessage(msg);
                         ad.setLongMessage(i18nc("Advice on making the best (long)", "Take care to your alarms.<br> %1.", msg));
                         QList<SKGAdvice::SKGAdviceAction> autoCorrections;
