@@ -25,6 +25,7 @@
 
 #include "skginterfaceplugin.h"
 #include "ui_skgsearchpluginwidget_pref.h"
+#include "skgruleobject.h"
 
 class SKGDocumentBank;
 class QAction;
@@ -152,7 +153,7 @@ public:
 
 private Q_SLOTS:
     void raiseAlarms();
-    void execute();
+    void execute(SKGRuleObject::ProcessMode iMode);
     void find();
 
 private:
@@ -164,10 +165,6 @@ private:
     Ui::skgsearchplugin_pref ui;
     QString m_docUniqueIdentifier;
     QTimer m_timer;
-    QAction* m_executeAll;
-    QAction* m_executeImported;
-    QAction* m_executeNotValidated;
-    QAction* m_searchAction;
 };
 
 #endif  // SKGSEARCHPLUGIN_H
