@@ -53,53 +53,44 @@ SKGSearchPluginWidget::SKGSearchPluginWidget(SKGDocument* iDocument)
     ui.kView->getShowWidget()->setDefaultState("search;update;alarm;highlighted");
 
     // Add Standard KDE Icons to buttons
-    ui.kUpdate->setIcon(QIcon::fromTheme("dialog-ok-apply"));
-    ui.kAdd->setIcon(QIcon::fromTheme("list-add"));
-    ui.kSearch->setIcon(QIcon::fromTheme("edit-find"));
+    ui.kUpdate->setIcon(SKGServices::fromTheme("dialog-ok"));
+    ui.kAdd->setIcon(SKGServices::fromTheme("list-add"));
+    ui.kSearch->setIcon(SKGServices::fromTheme("edit-find"));
     QStringList overlayopen;
     overlayopen.push_back("quickopen");
     ui.kOpenReport->setIcon(SKGServices::fromTheme("view-statistics", overlayopen));
 
-    ui.kTopBtn->setIcon(QIcon::fromTheme("arrow-up-double"));
-    ui.kUpBtn->setIcon(QIcon::fromTheme("arrow-up"));
-    ui.kDownBtn->setIcon(QIcon::fromTheme("arrow-down"));
-    ui.kBottomBtn->setIcon(QIcon::fromTheme("arrow-down-double"));
+    ui.kTopBtn->setIcon(SKGServices::fromTheme("arrow-up-double"));
+    ui.kUpBtn->setIcon(SKGServices::fromTheme("arrow-up"));
+    ui.kDownBtn->setIcon(SKGServices::fromTheme("arrow-down"));
+    ui.kBottomBtn->setIcon(SKGServices::fromTheme("arrow-down-double"));
 
     {
         SKGWidgetSelector::SKGListQWidget list;
         list.push_back(ui.kQueryGrp);
         list.push_back(ui.kBtnFrm);
-        ui.kWidgetSelector->addButton(QIcon::fromTheme("edit-find"), i18n("Search"), i18n("Display the edit panel for searches"), list);
+        ui.kWidgetSelector->addButton(SKGServices::fromTheme("edit-find"), i18n("Search"), i18n("Display the edit panel for searches"), list);
     }
     {
         SKGWidgetSelector::SKGListQWidget list;
         list.push_back(ui.kQueryGrp);
         list.push_back(ui.kBtnFrm);
         list.push_back(ui.kActionGrp);
-        ui.kWidgetSelector->addButton(QIcon::fromTheme("view-refresh"), i18n("Update"), i18n("Display the edit panel for updates"), list);
+        ui.kWidgetSelector->addButton(SKGServices::fromTheme("view-refresh"), i18n("Update"), i18n("Display the edit panel for updates"), list);
     }
     {
         SKGWidgetSelector::SKGListQWidget list;
         list.push_back(ui.kQueryGrp);
         list.push_back(ui.kBtnFrm);
         list.push_back(ui.kAlarmFrm);
-        ui.kWidgetSelector->addButton(QIcon::fromTheme("dialog-warning"), i18n("Alarm"), i18n("Display the edit panel for alarm"), list);
+        ui.kWidgetSelector->addButton(SKGServices::fromTheme("dialog-warning"), i18n("Alarm"), i18n("Display the edit panel for alarm"), list);
     }
     {
         SKGWidgetSelector::SKGListQWidget list;
         list.push_back(ui.kQueryGrp);
         list.push_back(ui.kBtnFrm);
         list.push_back(ui.kTemplateFrm);
-        ui.kWidgetSelector->addButton(QIcon::fromTheme("edit-guides"), i18n("Template"), i18n("Display the edit panel for updates by templates"), list);
-    }
-
-    // Fill combo boxes
-    SKGStringListList result;
-    iDocument->executeSelectSqliteOrder("SELECT id, t_displayname FROM v_operation_displayname WHERE t_template='Y' ORDER BY t_displayname", result);
-    int nb2 = result.count();
-    for (int i = 1; i < nb2; ++i) {  // Ignore header
-        QStringList r = result.at(i);
-        ui.kTemplate->addItem(r.at(1), r.at(0));
+        ui.kWidgetSelector->addButton(SKGServices::fromTheme("edit-guides"), i18n("Template"), i18n("Display the edit panel for updates by templates"), list);
     }
 
     QStringList attributeForQuery;
@@ -127,7 +118,7 @@ SKGSearchPluginWidget::SKGSearchPluginWidget(SKGDocument* iDocument)
     // Add registered global action in contextual menu
     if (SKGMainPanel::getMainPanel()) {
         QMenu* menu = new QMenu(this);
-        menu->setIcon(QIcon::fromTheme("system-run"));
+        menu->setIcon(SKGServices::fromTheme("system-run"));
         menu->addAction(SKGMainPanel::getMainPanel()->getGlobalAction("execute_all"));
         menu->addAction(SKGMainPanel::getMainPanel()->getGlobalAction("execute_imported"));
         menu->addAction(SKGMainPanel::getMainPanel()->getGlobalAction("execute_not_validated"));
@@ -239,6 +230,17 @@ void SKGSearchPluginWidget::dataModified(const QString& iTableName, int iIdTrans
     if (iTableName == "unit" || iTableName.isEmpty()) {
         ui.kAlarmUnit->setText(static_cast<SKGDocumentBank*>(getDocument())->getPrimaryUnit().Symbol);
     }
+
+    if (iTableName == "operation" || iTableName.isEmpty()) {
+        // Fill combo boxes
+        SKGStringListList result;
+        getDocument()->executeSelectSqliteOrder("SELECT id, t_displayname FROM v_operation_displayname WHERE t_template='Y' ORDER BY t_displayname", result);
+        int nb2 = result.count();
+        for (int i = 1; i < nb2; ++i) {  // Ignore header
+            QStringList r = result.at(i);
+            ui.kTemplate->addItem(r.at(1), r.at(0));
+        }
+    }
 }
 
 void SKGSearchPluginWidget::onAddRule()
