@@ -58,7 +58,7 @@ public:
      * Get the current selection
      * @return selected objects
      */
-    virtual SKGObjectBase::SKGListSKGObjectBase getSelectedObjects();
+    virtual SKGObjectBase::SKGListSKGObjectBase getSelectedObjects() Q_DECL_OVERRIDE;
 
     /**
      * Get the number of seleted object
@@ -119,7 +119,7 @@ protected:
      * @param iEvent event
      * @return In your reimplementation of this function, if you want to filter the event out, i.e. stop it being handled further, return true; otherwise return false.
      */
-    virtual bool eventFilter(QObject* iObject, QEvent* iEvent);
+    virtual bool eventFilter(QObject* iObject, QEvent* iEvent) Q_DECL_OVERRIDE;
 
 private Q_SLOTS:
     void dataModified(const QString& iTableName, int iIdTransaction);
