@@ -50,8 +50,8 @@ SKGTrackerPluginWidget::SKGTrackerPluginWidget(SKGDocument* iDocument)
     ui.kNameLbl->setText(i18n("%1:", iDocument->getDisplay("t_name")));
     ui.kCommentLabel->setText(i18n("%1:", iDocument->getDisplay("t_comment")));
 
-    ui.kAddButton->setIcon(QIcon::fromTheme("list-add"));
-    ui.kModifyButton->setIcon(QIcon::fromTheme("dialog-ok-apply"));
+    ui.kAddButton->setIcon(SKGServices::fromTheme("list-add"));
+    ui.kModifyButton->setIcon(SKGServices::fromTheme("dialog-ok"));
 
     ui.kView->setModel(new SKGObjectModel(static_cast<SKGDocumentBank*>(getDocument()), "v_refund_display", "1=0", this, "", false));
 
