@@ -72,13 +72,13 @@ bool SKGUnitPlugin::setupActions(SKGDocument* iDocument, const QStringList& iArg
     setXMLFile("skrooge_unit.rc");
 
     // Menu
-    QAction* actSplitShare = new QAction(QIcon::fromTheme("format-text-strikethrough"), i18nc("Verb", "Split share..."), this);
+    QAction* actSplitShare = new QAction(SKGServices::fromTheme("format-text-strikethrough"), i18nc("Verb", "Split share..."), this);
     connect(actSplitShare, &QAction::triggered, this, &SKGUnitPlugin::onSplitShare);
     actionCollection()->setDefaultShortcut(actSplitShare, Qt::ALT + Qt::Key_Slash);
     registerGlobalAction("edit_split_stock", actSplitShare, QStringList() << "unit", 1, 1, 310);  // TODO (Stephane MANKOWSKI): must be a share
 
     // -----------
-    QAction* act = new QAction(QIcon::fromTheme(icon()), i18nc("Verb", "Delete unused units"), this);
+    QAction* act = new QAction(SKGServices::fromTheme(icon()), i18nc("Verb", "Delete unused units"), this);
     connect(act, &QAction::triggered, this, &SKGUnitPlugin::deleteUnusedUnits);
     registerGlobalAction("clean_delete_unused_units", act);
     return true;
@@ -127,7 +127,10 @@ void SKGUnitPlugin::refresh()
                     IFOK(err) {
                         // Create default unit
                         SKGUnitObject unit;
-                        err = SKGUnitObject::createCurrencyUnit(m_currentBankDocument, QLocale().currencySymbol(QLocale::CurrencyIsoCode), unit);
+                        QString unitS = QLocale().currencySymbol(QLocale::CurrencyIsoCode);
+                        if (!unitS.isEmpty()) {
+                            err = SKGUnitObject::createCurrencyUnit(m_currentBankDocument, unitS, unit);
+                        }
 
                         // The file is considered has not modified
                         m_currentBankDocument->setFileNotModified();
