@@ -24,7 +24,6 @@
 #include "skginterfaceplugin.h"
 #include "ui_skgunitpluginwidget_pref.h"
 
-class QAction;
 class SKGDocumentBank;
 
 /**
@@ -158,8 +157,6 @@ private:
     SKGDocumentBank* m_currentBankDocument;
     QString m_docUniqueIdentifier;
 
-    QAction* m_splitShareAction;
-
     Ui::skgunitplugin_pref ui;
 };
 
