@@ -108,11 +108,11 @@ SKGUnitPluginWidget::SKGUnitPluginWidget(SKGDocumentBank* iDocument)
     ui.kUnitCreatorUnit->setWhereClauseCondition("t_type IN ('1','2','C')");
 
     // Add Standard KDE Icons to buttons to Accounts
-    ui.kUnitAdd->setIcon(QIcon::fromTheme("list-add"));
-    ui.kUnitUpdate->setIcon(QIcon::fromTheme("dialog-ok-apply"));
-    ui.kUnitValueDownload->setIcon(QIcon::fromTheme("download"));
-    ui.kDeleteSource->setIcon(QIcon::fromTheme("edit-delete"));
-    ui.kGetNewHotStuff->setIcon(QIcon::fromTheme("get-hot-new-stuff"));
+    ui.kUnitAdd->setIcon(SKGServices::fromTheme("list-add"));
+    ui.kUnitUpdate->setIcon(SKGServices::fromTheme("dialog-ok"));
+    ui.kUnitValueDownload->setIcon(SKGServices::fromTheme("download"));
+    ui.kDeleteSource->setIcon(SKGServices::fromTheme("edit-delete"));
+    ui.kGetNewHotStuff->setIcon(SKGServices::fromTheme("get-hot-new-stuff"));
 
     QRegExpValidator* newValidator = new QRegExpValidator(QRegExp("^[\\w\\s]+$"), this);
     ui.kDownloadSource->setValidator(newValidator);
@@ -126,38 +126,38 @@ SKGUnitPluginWidget::SKGUnitPluginWidget(SKGDocumentBank* iDocument)
     menu->addAction(m_upload);
     ui.kGetNewHotStuff->setMenu(menu);
 
-    ui.kUnitOpen->setIcon(QIcon::fromTheme("quickopen"));
+    ui.kUnitOpen->setIcon(SKGServices::fromTheme("quickopen"));
     connect(ui.kUnitOpen, &QPushButton::clicked, this, &SKGUnitPluginWidget::onOpenURL);
 
-    QAction* downloadLastAction = new QAction(QIcon::fromTheme("download"), i18n("download last value only"), this);
+    QAction* downloadLastAction = new QAction(SKGServices::fromTheme("download"), i18n("download last value only"), this);
     downloadLastAction->setData(SKGUnitObject::LAST);
     connect(downloadLastAction, &QAction::triggered, this, &SKGUnitPluginWidget::onDownloadUnitValue);
 
-    QAction* downloadLastMonthlyAction = new QAction(QIcon::fromTheme("download"), i18n("download monthly values since last known value"), this);
+    QAction* downloadLastMonthlyAction = new QAction(SKGServices::fromTheme("download"), i18n("download monthly values since last known value"), this);
     downloadLastMonthlyAction->setData(SKGUnitObject::LAST_MONTHLY);
     connect(downloadLastMonthlyAction, &QAction::triggered, this, &SKGUnitPluginWidget::onDownloadUnitValue);
 
-    QAction* downloadLastWeeklyAction = new QAction(QIcon::fromTheme("download"), i18n("download weekly values since last known value"), this);
+    QAction* downloadLastWeeklyAction = new QAction(SKGServices::fromTheme("download"), i18n("download weekly values since last known value"), this);
     downloadLastWeeklyAction->setData(SKGUnitObject::LAST_WEEKLY);
     connect(downloadLastWeeklyAction, &QAction::triggered, this, &SKGUnitPluginWidget::onDownloadUnitValue);
 
-    QAction* downloadLastDailyAction = new QAction(QIcon::fromTheme("download"), i18n("download daily values since last known value"), this);
+    QAction* downloadLastDailyAction = new QAction(SKGServices::fromTheme("download"), i18n("download daily values since last known value"), this);
     downloadLastDailyAction->setData(SKGUnitObject::LAST_DAILY);
     connect(downloadLastDailyAction, &QAction::triggered, this, &SKGUnitPluginWidget::onDownloadUnitValue);
 
-    QAction* downloadMonthlyAction = new QAction(QIcon::fromTheme("download"), i18n("download all monthly values"), this);
+    QAction* downloadMonthlyAction = new QAction(SKGServices::fromTheme("download"), i18n("download all monthly values"), this);
     downloadMonthlyAction->setData(SKGUnitObject::ALL_MONTHLY);
     connect(downloadMonthlyAction, &QAction::triggered, this, &SKGUnitPluginWidget::onDownloadUnitValue);
 
-    QAction* downloadWeeklyAction = new QAction(QIcon::fromTheme("download"), i18n("download all weekly values"), this);
+    QAction* downloadWeeklyAction = new QAction(SKGServices::fromTheme("download"), i18n("download all weekly values"), this);
     downloadWeeklyAction->setData(SKGUnitObject::ALL_WEEKLY);
     connect(downloadWeeklyAction, &QAction::triggered, this, &SKGUnitPluginWidget::onDownloadUnitValue);
 
-    QAction* downloadDailyAction = new QAction(QIcon::fromTheme("download"), i18n("download all daily values"), this);
+    QAction* downloadDailyAction = new QAction(SKGServices::fromTheme("download"), i18n("download all daily values"), this);
     downloadDailyAction->setData(SKGUnitObject::ALL_DAILY);
     connect(downloadDailyAction, &QAction::triggered, this, &SKGUnitPluginWidget::onDownloadUnitValue);
 
-    QAction* simplifyAction = new QAction(QIcon::fromTheme("edit-delete"), i18n("simplify values"), this);
+    QAction* simplifyAction = new QAction(SKGServices::fromTheme("edit-delete"), i18n("simplify values"), this);
     connect(simplifyAction, &QAction::triggered, this, &SKGUnitPluginWidget::onSimplify);
 
 
@@ -177,19 +177,19 @@ SKGUnitPluginWidget::SKGUnitPluginWidget(SKGDocumentBank* iDocument)
         SKGWidgetSelector::SKGListQWidget list;
         list.push_back(ui.kStandardFrm);
         list.push_back(ui.kBtnFrm);
-        ui.kWidgetSelector->addButton(QIcon::fromTheme("dialog-ok-apply"), i18n("Standard"), i18n("Display the edit panel for standard units"), list);
+        ui.kWidgetSelector->addButton(SKGServices::fromTheme("dialog-ok"), i18n("Standard"), i18n("Display the edit panel for standard units"), list);
     }
     {
         SKGWidgetSelector::SKGListQWidget list;
         list.push_back(ui.kManualFrm);
         list.push_back(ui.kBtnFrm);
-        ui.kWidgetSelector->addButton(QIcon::fromTheme("user-properties"), i18n("Manual / Share"), i18n("Display the edit panel for manual units"), list);
+        ui.kWidgetSelector->addButton(SKGServices::fromTheme("user-properties"), i18n("Manual / Share"), i18n("Display the edit panel for manual units"), list);
     }
     {
         SKGWidgetSelector::SKGListQWidget list;
         list.push_back(ui.kValuesFrm);
         list.push_back(ui.kBtnFrm);
-        ui.kWidgetSelector->addButton(QIcon::fromTheme("taxes-finances"), i18n("Values"), i18n("Display the edit panel for values of units"), list);
+        ui.kWidgetSelector->addButton(SKGServices::fromTheme("taxes-finances"), i18n("Values"), i18n("Display the edit panel for values of units"), list);
     }
     connect(ui.kWidgetSelector, &SKGWidgetSelector::selectedModeChanged, this, &SKGUnitPluginWidget::onUnitCreatorModified);
 
