@@ -142,22 +142,22 @@ void SKGObjectModel::buidCache()
         m_fontDisabledScheduleColor = QVariant::fromValue(pref.readEntry("fontFutureColor", QColor(Qt::gray)));
     }
 
-    m_iconFavorite = QIcon::fromTheme("bookmarks");
+    m_iconFavorite = SKGServices::fromTheme("bookmarks");
 
     if (m_operationTable || m_recurrentoperationTable) {
-        m_iconTransfer = QIcon::fromTheme("view-financial-transfer");
+        m_iconTransfer = SKGServices::fromTheme("view-financial-transfer");
         QStringList overlays;
         overlays.push_back("list-remove");
         m_iconGroup = SKGServices::fromTheme("view-financial-transfer", overlays);
-        m_iconSplit = QIcon::fromTheme("split");
-        m_iconImported = QIcon::fromTheme("utilities-file-archiver");
+        m_iconSplit = SKGServices::fromTheme("split");
+        m_iconImported = SKGServices::fromTheme("utilities-file-archiver");
         {
             QStringList overlay;
             overlay.push_back("dialog-ok");
             m_iconImportedChecked = SKGServices::fromTheme("utilities-file-archiver", overlay);
         }
 
-        m_iconRecurrent = QIcon::fromTheme("chronometer");
+        m_iconRecurrent = SKGServices::fromTheme("chronometer");
         {
             QStringList overlay;
             overlay.push_back("bookmarks");
@@ -166,30 +166,30 @@ void SKGObjectModel::buidCache()
     }
 
     if (m_budgetTable) {
-        m_iconGreen = QIcon::fromTheme("security-high");
-        m_iconRed = QIcon::fromTheme("security-low");
-        m_iconAnber = QIcon::fromTheme("security-medium");
+        m_iconGreen = SKGServices::fromTheme("security-high");
+        m_iconRed = SKGServices::fromTheme("security-low");
+        m_iconAnber = SKGServices::fromTheme("security-medium");
     }
 
     if (m_unitTable) {
-        m_iconMuchMore = QIcon::fromTheme("skrooge_much_more");
-        m_iconMuchLess = QIcon::fromTheme("skrooge_much_less");
-        m_iconMore = QIcon::fromTheme("skrooge_more");
-        m_iconLess = QIcon::fromTheme("skrooge_less");
+        m_iconMuchMore = SKGServices::fromTheme("skrooge_much_more");
+        m_iconMuchLess = SKGServices::fromTheme("skrooge_much_less");
+        m_iconMore = SKGServices::fromTheme("skrooge_more");
+        m_iconLess = SKGServices::fromTheme("skrooge_less");
     }
 
     if (m_ruleTable) {
-        m_iconSearch = QIcon::fromTheme("edit-find");
-        m_iconUpdate = QIcon::fromTheme("view-refresh");
-        m_iconAlarm = QIcon::fromTheme("dialog-warning");
-        m_iconTemplate = QIcon::fromTheme("edit-guides");
+        m_iconSearch = SKGServices::fromTheme("edit-find");
+        m_iconUpdate = SKGServices::fromTheme("view-refresh");
+        m_iconAlarm = SKGServices::fromTheme("dialog-warning");
+        m_iconTemplate = SKGServices::fromTheme("edit-guides");
     }
-    m_iconClosed = QIcon::fromTheme("dialog-close");
+    m_iconClosed = SKGServices::fromTheme("dialog-close");
 
     if (m_categoryTable) {
-        m_iconCategory = QIcon::fromTheme("view-categories");
-        m_iconCategoryMoins = QIcon::fromTheme("view-categories-expenditures");
-        m_iconCategoryPlus = QIcon::fromTheme("view-categories-incomes");
+        m_iconCategory = SKGServices::fromTheme("view-categories");
+        m_iconCategoryMoins = SKGServices::fromTheme("view-categories-expenditures");
+        m_iconCategoryPlus = SKGServices::fromTheme("view-categories-incomes");
     }
 }
 
@@ -321,6 +321,7 @@ QVariant SKGObjectModel::data(const QModelIndex& iIndex, int iRole) const
             if (iRole == Qt::DisplayRole) {
                 if (att.endsWith(QLatin1String("_INCOME")) ||
                     att.endsWith(QLatin1String("_EXPENSE")) ||
+                    (m_operationTable && obj->getAttribute("t_template") == "Y") ||
                     (m_categoryTable && (att == "f_REALCURRENTAMOUNT" ||
                                          att == "f_SUMCURRENTAMOUNT"))) {
                     if (dval == 0) {
@@ -477,17 +478,17 @@ QVariant SKGObjectModel::data(const QModelIndex& iIndex, int iRole) const
             else if (att == "t_TYPENLS") {
                 QString type = obj->getAttribute("t_type");
                 if (type == "C") {
-                    return QIcon::fromTheme("view-bank-account-savings");
+                    return SKGServices::fromTheme("view-bank-account-savings");
                 } else if (type == "D")  {
-                    return QIcon::fromTheme("view-credit-card-account");
+                    return SKGServices::fromTheme("view-credit-card-account");
                 } else if (type == "I")  {
-                    return QIcon::fromTheme("view-stock-account");
+                    return SKGServices::fromTheme("view-stock-account");
                 } else if (type == "A")  {
-                    return QIcon::fromTheme("view-loan-asset");
+                    return SKGServices::fromTheme("view-loan-asset");
                 } else if (type == "W")  {
-                    return QIcon::fromTheme("kwalletmanager");
+                    return SKGServices::fromTheme("kwalletmanager");
                 } else {
-                    return QIcon::fromTheme();
+                    return SKGServices::fromTheme();
                 }
             }
 #endif
@@ -828,20 +829,21 @@ bool SKGObjectModel::setData(const QModelIndex& iIndex, const QVariant& iValue,
     if (iRole == Qt::CheckStateRole) {
         SKGError err;
         {
+            Qt::CheckState newState = static_cast<Qt::CheckState>(iValue.toInt());
             if (m_accountTable) {
                 SKGAccountObject obj(getObject(iIndex));
                 SKGBEGINLIGHTTRANSACTION(*getDocument(),
-                                         (static_cast<Qt::CheckState>(iValue.toInt()) == Qt::Checked ? i18nc("Noun, name of the user action", "Close account '%1'", obj.getName()) : i18nc("Noun, name of the user action", "Open account '%1'", obj.getName())), err);
-                if (qAbs(obj.getCurrentAmount()) > 0.01) {
+                                         (newState == Qt::Checked ? i18nc("Noun, name of the user action", "Close account '%1'", obj.getName()) : i18nc("Noun, name of the user action", "Open account '%1'", obj.getName())), err);
+                if (qAbs(obj.getCurrentAmount()) > 0.01 && newState == Qt::Checked) {
                     err = getDocument()->sendMessage(i18nc("An information message",  "Warning, you closed an account with money"), SKGDocument::Warning);
                 }
-                IFOKDO(err, obj.setClosed(static_cast<Qt::CheckState>(iValue.toInt()) == Qt::Checked))
+                IFOKDO(err, obj.setClosed(newState == Qt::Checked))
                 IFOKDO(err, obj.save())
             } else if (m_trackerTable) {
                 SKGTrackerObject obj(getObject(iIndex));
                 SKGBEGINLIGHTTRANSACTION(*getDocument(),
-                                         (static_cast<Qt::CheckState>(iValue.toInt()) == Qt::Checked ? i18nc("Noun, name of the user action", "Close tracker '%1'", obj.getName()) : i18nc("Noun, name of the user action", "Open tracker '%1'", obj.getName())), err);
-                err = obj.setClosed(static_cast<Qt::CheckState>(iValue.toInt()) == Qt::Checked);
+                                         (newState == Qt::Checked ? i18nc("Noun, name of the user action", "Close tracker '%1'", obj.getName()) : i18nc("Noun, name of the user action", "Open tracker '%1'", obj.getName())), err);
+                err = obj.setClosed(newState == Qt::Checked);
                 IFOKDO(err, obj.save())
             } else if (m_operationTable) {
                 // Get the real object, not the object from the view
