@@ -49,8 +49,8 @@ SKGQueryCreator::SKGQueryCreator(QWidget* iParent)
     ui.kList->horizontalHeader()->setSectionsMovable(true);
 
 
-    ui.kToolHelp->setIcon(QIcon::fromTheme("dialog-information"));
-    ui.kCheckMode->setIcon(QIcon::fromTheme("arrow-down"));
+    ui.kToolHelp->setIcon(SKGServices::fromTheme("dialog-information"));
+    ui.kCheckMode->setIcon(SKGServices::fromTheme("arrow-down"));
     ui.kCheckMode->setToolTip(i18nc("A tool tip", "Switch in advanced mode"));
 
     connect(ui.kCheckMode, &QToolButton::clicked, this, &SKGQueryCreator::switchAdvancedSearchMode);
@@ -76,13 +76,13 @@ void SKGQueryCreator::setAdvancedSearchMode(bool iAdvancedMode) const
         ui.kToolHelp->hide();
         ui.kFrmAdvanced->show();
         ui.kFilterEdit->hide();
-        ui.kCheckMode->setIcon(QIcon::fromTheme("arrow-up"));
+        ui.kCheckMode->setIcon(SKGServices::fromTheme("arrow-up"));
         ui.kCheckMode->setToolTip(i18nc("A tool tip", "Switch in simple mode"));
     } else {
         ui.kToolHelp->show();
         ui.kFrmAdvanced->hide();
         ui.kFilterEdit->show();
-        ui.kCheckMode->setIcon(QIcon::fromTheme("arrow-down"));
+        ui.kCheckMode->setIcon(SKGServices::fromTheme("arrow-down"));
         ui.kCheckMode->setToolTip(i18nc("A tool tip", "Switch in advanced mode"));
     }
 }
@@ -104,7 +104,7 @@ void SKGQueryCreator::setParameters(SKGDocument* iDocument, const QString& iTabl
 
 //     QString txt=(updateMode ? i18nc("Description", "Double click on a field name to add it to your modification definition.") : i18nc("Description", "Double click on a field name to add it to your search definition."))+'\n'+i18nc("Description", "Double click on a cell to modify it.");
 //     ui.kLabel->setComment ( "<html><body><b>"+SKGServices::stringToHtml ( txt ) +"</b></body></html>" );
-//     ui.kLabel->setPixmap ( QIcon::fromTheme( updateMode ? "view-refresh" :"edit-find" ).pixmap ( 22, 22 ), KTitleWidget::ImageLeft );
+//     ui.kLabel->setPixmap ( SKGServices::fromTheme( updateMode ? "view-refresh" :"edit-find" ).pixmap ( 22, 22 ), KTitleWidget::ImageLeft );
 
     // Build list of attributes
     if (m_document) {
@@ -455,7 +455,7 @@ void SKGQueryCreator::addNewLine()
 
         // Add a delete icon
         if (!m_updateMode) {
-            ui.kList->setVerticalHeaderItem(row, new QTableWidgetItem(QIcon::fromTheme("edit-delete"), ""));
+            ui.kList->setVerticalHeaderItem(row, new QTableWidgetItem(SKGServices::fromTheme("edit-delete"), ""));
         }
 
         for (int i = 0; i < nbCol; ++i) {
