@@ -98,7 +98,7 @@ public:
      * Operator affectation
      * @param iObject the object to copy
      */
-    virtual const SKGAccountObject& operator= (const SKGObjectBase& iObject);
+    virtual const SKGAccountObject& operator= (const SKGObjectBase& iObject) Q_DECL_OVERRIDE;
 
     /**
      * Destructor
