@@ -105,6 +105,13 @@ public Q_SLOTS:
      */
     virtual SKGServices::SKGUnitInfo getSecondaryUnit();
 
+    /**
+    * Get the preferred category for a payee. WARNING: This value can be not uptodated in a transaction.
+    * @param iPayee the payee
+    * @return The preferred category.
+    */
+    virtual QString getCategoryForPayee(const QString& iPayee);
+
     /**
      * Refresh all views and indexes in the database
      * @param iForce force the refresh
