@@ -82,7 +82,7 @@ public:
      * Operator affectation
      * @param iObject the object to copy
      */
-    virtual const SKGOperationObject& operator= (const SKGObjectBase& iObject);
+    virtual const SKGOperationObject& operator= (const SKGObjectBase& iObject) Q_DECL_OVERRIDE;
 
     /**
      * Destructor
