@@ -169,7 +169,7 @@ public:
      * @param iTracker the computation includes tracked operations
      * @return the income versus expenditure
      */
-    virtual QVariantList getIncomeVsExpenditure(bool iOnSubOperation = false, bool iTransfert = true, bool iTracker = true, const QString& iWhereClause1 = QString(), const QString& iWhereClause2 = QString());
+    virtual QVariantList getIncomeVsExpenditure(bool iOnSubOperation = true, bool iTransfert = false, bool iTracker = true, const QString& iWhereClause1 = QString(), const QString& iWhereClause2 = QString());
 
 protected:
     /**
