@@ -269,7 +269,7 @@ SKGError SKGRuleObject::execute(ProcessMode iMode)
             SKGRuleObject::SKGAlarmInfo alarm = getAlarmInfo();
             if (!alarm.Message.isEmpty()) {
                 SKGServices::SKGUnitInfo unit = doc->getPrimaryUnit();
-                getDocument()->sendMessage(alarm.Message.arg(doc->formatMoney(alarm.Amount, unit, false)).arg(doc->formatMoney(alarm.Limit, unit, false)).arg(doc->formatMoney(alarm.Amount - alarm.Limit, unit, false)));
+                getDocument()->sendMessage(alarm.Message.arg(doc->formatMoney(alarm.Amount, unit, false), doc->formatMoney(alarm.Limit, unit, false), doc->formatMoney(alarm.Amount - alarm.Limit, unit, false)));
             }
         }
     } else if (getActionType() == SKGRuleObject::APPLYTEMPLATE) {
@@ -364,7 +364,7 @@ QString SKGRuleObject::getDisplayForOperator(const QString& iOperator, const QSt
         output = i18nc("Description of a condition. Do not translate key words (#V1S#, #V1#, ...)", "<='#V1S#'").replace("#V1S#", iParam1);
     } else if (output == "#ATT#>=#V1# AND #ATT#<=#V2#") {
         output = i18nc("Description of a condition. Do not translate key words (#V1S#, #V1#, ...)", "is between #V1# and #V2#").replace("#V1#", iParam1).replace("#V2#", iParam2);
-    } else if (output == "#ATT#>='#V1S#' AND #ATT#<='#V2S#'") {
+    } else if (output == "((#ATT#>='#V1S#' AND #ATT#<='#V2S#') OR (#ATT#>='#V2S#' AND #ATT#<='#V1S#'))") {
         output = i18nc("Description of a condition. Do not translate key words (#V1S#, #V1#, ...)", "is between '#V1S#' and '#V2S#'").replace("#V1S#", iParam1).replace("#V2S#", iParam2);
     } else if (output == "#ATT#=lower(#ATT#)") {
         output = i18nc("Description of a condition. Do not translate key words (#V1S#, #V1#, ...)", "is set to lower");
@@ -497,7 +497,7 @@ QStringList SKGRuleObject::getListOfOperators(SKGServices::AttributeType iAttrib
             output.push_back("#ATT#<'#V1S#'");
             output.push_back("#ATT#>='#V1S#'");
             output.push_back("#ATT#<='#V1S#'");
-            output.push_back("#ATT#>='#V1S#' AND #ATT#<='#V2S#'");
+            output.push_back("((#ATT#>='#V1S#' AND #ATT#<='#V2S#') OR (#ATT#>='#V2S#' AND #ATT#<='#V1S#'))");
         }
 
         if (iAttributeType == SKGServices::DATE) {
