@@ -95,7 +95,7 @@ public:
      * Operator affectation
      * @param iObject the object to copy
      */
-    virtual const SKGRuleObject& operator= (const SKGObjectBase& iObject);
+    virtual const SKGRuleObject& operator= (const SKGObjectBase& iObject) Q_DECL_OVERRIDE;
 
     /**
      * Destructor
@@ -249,7 +249,7 @@ public:
      * @return an object managing the error
      *   @see SKGError
      */
-    virtual SKGError save(bool iInsertOrUpdate = true, bool iReloadAfterSave = true);
+    virtual SKGError save(bool iInsertOrUpdate = true, bool iReloadAfterSave = true) Q_DECL_OVERRIDE;
 
     /**
      * Execute actions
