@@ -99,7 +99,7 @@ public:
      * Operator affectation
      * @param iObject the object to copy
      */
-    virtual const SKGUnitObject& operator= (const SKGObjectBase& iObject);
+    virtual const SKGUnitObject& operator= (const SKGObjectBase& iObject) Q_DECL_OVERRIDE;
 
     /**
      * Get unit information
@@ -400,7 +400,7 @@ protected:
      * For this class, the whereclause is based on name
      * @return the where clause
      */
-    virtual QString getWhereclauseId() const;
+    virtual QString getWhereclauseId() const Q_DECL_OVERRIDE;
 };
 /**
  * Declare the class
