@@ -41,6 +41,7 @@ public:
 
     QStringList keywords;
     KDateValidator::FixupBehavior behavior;
+    QString mAlternativeDateFormatToUse;
 };
 
 }
@@ -50,6 +51,10 @@ using namespace KPIM;
 KDateValidator::KDateValidator(QObject* iParent)
     : QValidator(iParent), d(new KDateValidatorPrivate)
 {
+    // Check if we can use the QLocale::ShortFormat
+    if (!QLocale().toString(QDate(2015, 1, 1), QLocale::ShortFormat).contains("2015")) {
+        d->mAlternativeDateFormatToUse = "dd/MM/yyyy";
+    }
 }
 
 KDateValidator::~KDateValidator()
@@ -70,7 +75,7 @@ QValidator::State KDateValidator::validate(QString& str, int& /*pos*/) const
         return Acceptable;
     }
 
-    QDate date = QLocale().toDate(str, QLocale::ShortFormat);
+    QDate date = (d->mAlternativeDateFormatToUse.isEmpty() ? QLocale().toDate(str, QLocale::ShortFormat) : QLocale().toDate(str, d->mAlternativeDateFormatToUse));
     if (date.isValid()) {
         return Acceptable;
     } else {
@@ -86,7 +91,7 @@ void KDateValidator::fixup(QString& input) const
 
     QDate result = SKGServices::partialStringToDate(input, d->behavior == FixupBackward);
     if (result.isValid()) {
-        input = QLocale().toString(result, QLocale::ShortFormat);
+        input = (d->mAlternativeDateFormatToUse.isEmpty() ? QLocale().toString(result, QLocale::ShortFormat) : QLocale().toString(result, d->mAlternativeDateFormatToUse));
     }
 }
 
