@@ -50,8 +50,8 @@ SKGGraphicsView::SKGGraphicsView(QWidget* iParent)
     graphicsView()->installEventFilter(this);
 
     // Set icons
-    ui.kPrint->setIcon(QIcon::fromTheme("printer"));
-    ui.kCopy->setIcon(QIcon::fromTheme("edit-copy"));
+    ui.kPrint->setIcon(SKGServices::fromTheme("printer"));
+    ui.kCopy->setIcon(SKGServices::fromTheme("edit-copy"));
 
     // Build contextual menu
     graphicsView()->setContextMenuPolicy(Qt::CustomContextMenu);
@@ -74,7 +74,7 @@ SKGGraphicsView::SKGGraphicsView(QWidget* iParent)
         zoomMenu->setValue(val);
     });
 
-    m_actShowToolBar = m_mainMenu->addAction(QIcon::fromTheme("show-menu"), i18nc("Noun, user action", "Show tool bar"));
+    m_actShowToolBar = m_mainMenu->addAction(SKGServices::fromTheme("show-menu"), i18nc("Noun, user action", "Show tool bar"));
     if (m_actShowToolBar) {
         m_actShowToolBar->setCheckable(true);
         m_actShowToolBar->setChecked(true);
@@ -89,7 +89,7 @@ SKGGraphicsView::SKGGraphicsView(QWidget* iParent)
     QAction* actPrint = m_mainMenu->addAction(ui.kPrint->icon(), ui.kPrint->toolTip());
     connect(actPrint, &QAction::triggered, this, &SKGGraphicsView::onPrint);
 
-    QAction* actExport = m_mainMenu->addAction(QIcon::fromTheme("document-export"), i18nc("Noun, user action", "Export..."));
+    QAction* actExport = m_mainMenu->addAction(SKGServices::fromTheme("document-export"), i18nc("Noun, user action", "Export..."));
     connect(actExport, &QAction::triggered, this, &SKGGraphicsView::onExport);
 
     connect(graphicsView(), &QHeaderView::customContextMenuRequested, this, &SKGGraphicsView::showMenu);
