@@ -185,14 +185,14 @@ public:
             progressBar->setValue(iPos);
             progressBar->setVisible(visible);
             if (iPos == 100) {
-                QTimer::singleShot(300, Qt::CoarseTimer, progressBar, SLOT(hide()));
+                QTimer::singleShot(300, Qt::CoarseTimer, progressBar, &QProgressBar::hide);
             }
             progressBar->setToolTip(iName);
         }
         if (button) {
             button->setVisible(visible);
             if (iPos == 100) {
-                QTimer::singleShot(300, Qt::CoarseTimer, button, SLOT(hide()));
+                QTimer::singleShot(300, Qt::CoarseTimer, button, &QPushButton::hide);
             }
         }
 
@@ -418,9 +418,6 @@ SKGMainPanel::SKGMainPanel(QSplashScreen* iSplashScreen, SKGDocument* iDocument,
     if (QSystemTrayIcon::isSystemTrayAvailable()) {
         d->m_kSystemTrayIcon = new QSystemTrayIcon(qApp->windowIcon());
         QMenu* systemTrayMenu = new QMenu(this);
-        QAction* quit = systemTrayMenu->addAction(QIcon::fromTheme("application-exit"),  i18nc("Verb", "Quit"));
-        connect(quit, &QAction::triggered, this, &SKGMainPanel::onQuitAction);
-
         d->m_kSystemTrayIcon->setContextMenu(systemTrayMenu);
         connect(d->m_kSystemTrayIcon, &QSystemTrayIcon::activated, this, &SKGMainPanel::onTrayActivated);
         if (d->iconInSystemtray()) {
@@ -460,7 +457,7 @@ SKGMainPanel::SKGMainPanel(QSplashScreen* iSplashScreen, SKGDocument* iDocument,
     connect(panelAction2, &QAction::triggered, toggle2, &QAction::trigger);
     connect(toggle2, &QAction::toggled, panelAction2, &QAction::setChecked);
 
-    KSelectAction* contextMenu = new KSelectAction(QIcon::fromTheme("tab-new"), i18nc("Noun", "Pages"), this);
+    KSelectAction* contextMenu = new KSelectAction(SKGServices::fromTheme("tab-new"), i18nc("Noun", "Pages"), this);
     registerGlobalAction("view_contextmenu" , contextMenu);
 
     // Add plugin in client in right order
@@ -480,7 +477,7 @@ SKGMainPanel::SKGMainPanel(QSplashScreen* iSplashScreen, SKGDocument* iDocument,
                 // Add menu item with shortcuts
                 if (pluginInterface->isInPagesChooser()) {
                     bool visible = prefContextVisibility.readEntry(pluginInterface->objectName(), true);
-                    QIcon icon = QIcon::fromTheme(pluginInterface->icon());
+                    QIcon icon = SKGServices::fromTheme(pluginInterface->icon());
 
                     QListWidgetItem* contextItem = new QListWidgetItem(icon, title);
                     contextItem->setStatusTip(pluginInterface->statusTip());
@@ -597,14 +594,14 @@ SKGMainPanel::SKGMainPanel(QSplashScreen* iSplashScreen, SKGDocument* iDocument,
     // Set Cancel button
     QPushButton* kCancelButton = new QPushButton();
     kCancelButton->setObjectName(QString::fromUtf8("kCancelButton"));
-    kCancelButton->setIcon(QIcon::fromTheme("media-playback-stop"));
+    kCancelButton->setIcon(SKGServices::fromTheme("media-playback-stop"));
     kCancelButton->setToolTip(i18nc("Widget description", "Cancel the current action"));
     kCancelButton->setStatusTip(i18nc("Widget description", "Cancel the current action"));
     kCancelButton->setVisible(false);
     connect(kCancelButton, &QPushButton::clicked, this, &SKGMainPanel::onCancelCurrentAction);
 
     //
-    d->ui.kClearMessageBtn->setIcon(QIcon::fromTheme("edit-clear"));
+    d->ui.kClearMessageBtn->setIcon(SKGServices::fromTheme("edit-clear"));
     connect(d->ui.kClearMessageBtn, &QPushButton::clicked, this, &SKGMainPanel::onClearMessages);
 
     // Add special button in toolbar
@@ -660,10 +657,10 @@ SKGMainPanel::SKGMainPanel(QSplashScreen* iSplashScreen, SKGDocument* iDocument,
     d->ui.kContextList->setContextMenuPolicy(Qt::CustomContextMenu);
 
     d->m_contextMenu = new QMenu(d->ui.kContextList);
-    d->m_actHideContextItem = d->m_contextMenu->addAction(QIcon::fromTheme("layer-visible-off"), i18nc("Verb", "Hide"));
+    d->m_actHideContextItem = d->m_contextMenu->addAction(SKGServices::fromTheme("layer-visible-off"), i18nc("Verb", "Hide"));
     connect(d->m_actHideContextItem, &QAction::triggered, this, &SKGMainPanel::onHideContextItem);
 
-    d->m_actShowAllContextItems = d->m_contextMenu->addAction(QIcon::fromTheme("layer-visible-on"), i18nc("Verb", "Show all"));
+    d->m_actShowAllContextItems = d->m_contextMenu->addAction(SKGServices::fromTheme("layer-visible-on"), i18nc("Verb", "Show all"));
     connect(d->m_actShowAllContextItems, &QAction::triggered, this, &SKGMainPanel::onShowAllContextItems);
 
     d->m_contextMenu->addSeparator();
@@ -903,7 +900,7 @@ void SKGMainPanel::setupActions()
     KStandardAction::preferences(this, SLOT(optionsPreferences()), actionCollection());
 
     // New Tab
-    QAction* actAddTab = new QAction(QIcon::fromTheme("tab-new-background"), i18nc("Noun, user action", "New Tab"), this);
+    QAction* actAddTab = new QAction(SKGServices::fromTheme("tab-new-background"), i18nc("Noun, user action", "New Tab"), this);
     actionCollection()->setDefaultShortcut(actAddTab, Qt::CTRL + Qt::SHIFT + Qt::Key_W);
     connect(actAddTab, &QAction::triggered, this, &SKGMainPanel::addTab);
     registerGlobalAction("new_tab", actAddTab, true, QStringList(), -1);
@@ -917,15 +914,15 @@ void SKGMainPanel::setupActions()
     addTabButton->setToolButtonStyle(Qt::ToolButtonIconOnly);
     d->m_tabWidget->setCornerWidget(addTabButton);
 
-    d->m_actLock = new QAction(QIcon::fromTheme("document-encrypt"), i18nc("Verb", "Lock panels"), this);
+    d->m_actLock = new QAction(SKGServices::fromTheme("document-encrypt"), i18nc("Verb", "Lock panels"), this);
     connect(d->m_actLock, &QAction::triggered, this, &SKGMainPanel::onLockDocks);
     registerGlobalAction("view_lock", d->m_actLock);
 
-    d->m_actUnLock = new QAction(QIcon::fromTheme("document-decrypt"), i18nc("Verb", "Unlock panels"), this);
+    d->m_actUnLock = new QAction(SKGServices::fromTheme("document-decrypt"), i18nc("Verb", "Unlock panels"), this);
     connect(d->m_actUnLock, &QAction::triggered, this, &SKGMainPanel::onUnlockDocks);
     registerGlobalAction("view_unlock", d->m_actUnLock);
 
-    d->m_switchPinState = new QAction(QIcon::fromTheme("document-encrypt"), i18nc("Noun, user action", "Pin this page"), this);
+    d->m_switchPinState = new QAction(SKGServices::fromTheme("document-encrypt"), i18nc("Noun, user action", "Pin this page"), this);
     connect(d->m_switchPinState, &QAction::triggered, [ = ] {this->switchPinPage();});
     registerGlobalAction("tab_switchpin", d->m_switchPinState);
 
@@ -934,31 +931,31 @@ void SKGMainPanel::setupActions()
     registerGlobalAction("tab_close", d->m_closePageAction);
 
     //
-    QAction* actCloseAllPages = new QAction(QIcon::fromTheme("window-close"), i18nc("Noun, user action", "Close All"), this);
+    QAction* actCloseAllPages = new QAction(SKGServices::fromTheme("window-close"), i18nc("Noun, user action", "Close All"), this);
     actionCollection()->setDefaultShortcut(actCloseAllPages, Qt::ALT + Qt::Key_W);
     connect(actCloseAllPages, &QAction::triggered, this, &SKGMainPanel::closeAllPages);
     registerGlobalAction("tab_closeall", actCloseAllPages, true, QStringList(), -1);
 
     //
-    d->m_closeAllOtherPagesAction = new QAction(QIcon::fromTheme("window-close"), i18nc("Noun, user action", "Close All Other"), this);
+    d->m_closeAllOtherPagesAction = new QAction(SKGServices::fromTheme("window-close"), i18nc("Noun, user action", "Close All Other"), this);
     actionCollection()->setDefaultShortcut(d->m_closeAllOtherPagesAction, Qt::CTRL + Qt::ALT + Qt::Key_W);
     connect(d->m_closeAllOtherPagesAction, &QAction::triggered, [ = ] {this->closeAllOtherPages();});
     registerGlobalAction("tab_closeallother", d->m_closeAllOtherPagesAction);
 
     //
-    d->m_saveDefaultStateAction = new QAction(QIcon::fromTheme("document-save"), i18nc("Noun, user action", "Save page state"), this);
+    d->m_saveDefaultStateAction = new QAction(SKGServices::fromTheme("document-save"), i18nc("Noun, user action", "Save page state"), this);
     actionCollection()->setDefaultShortcut(d->m_saveDefaultStateAction, Qt::CTRL + Qt::ALT + Qt::Key_S);
     connect(d->m_saveDefaultStateAction, &QAction::triggered, this, &SKGMainPanel::saveDefaultState);
     registerGlobalAction("tab_savedefaultstate", d->m_saveDefaultStateAction);
 
     //
-    d->m_resetDefaultStateAction = new QAction(QIcon::fromTheme("edit-clear"), i18nc("Noun, user action", "Reset page state"), this);
+    d->m_resetDefaultStateAction = new QAction(SKGServices::fromTheme("edit-clear"), i18nc("Noun, user action", "Reset page state"), this);
     actionCollection()->setDefaultShortcut(d->m_resetDefaultStateAction, Qt::CTRL + Qt::ALT + Qt::Key_R);
     connect(d->m_resetDefaultStateAction, &QAction::triggered, this, &SKGMainPanel::resetDefaultState);
     registerGlobalAction("tab_resetdefaultstate", d->m_resetDefaultStateAction);
 
     //
-    d->m_reopenLastClosed = new QAction(QIcon::fromTheme("tab-new"), i18nc("Noun, user action", "Reopen last page closed"), this);
+    d->m_reopenLastClosed = new QAction(SKGServices::fromTheme("tab-new"), i18nc("Noun, user action", "Reopen last page closed"), this);
     actionCollection()->setDefaultShortcut(d->m_reopenLastClosed, Qt::CTRL + Qt::ALT + Qt::Key_T);
     connect(d->m_reopenLastClosed, &QAction::triggered, this, &SKGMainPanel::onReopenLastClosed);
     registerGlobalAction("tab_reopenlastclosed", d->m_reopenLastClosed);
@@ -972,14 +969,14 @@ void SKGMainPanel::setupActions()
     registerGlobalAction("tab_overwritebookmark", d->m_overwriteBookmarkStateAction);
 
     //
-    d->m_configureAction = new QAction(QIcon::fromTheme("configure"), i18nc("Noun, user action", "Configure..."), this);
+    d->m_configureAction = new QAction(SKGServices::fromTheme("configure"), i18nc("Noun, user action", "Configure..."), this);
     connect(d->m_configureAction, &QAction::triggered, [ = ] {this->optionsPreferences();});
     registerGlobalAction("tab_configure", d->m_configureAction);
 
     d->m_tipOfDayAction = KStandardAction::tipOfDay(this, SLOT(onTipOfDay()), actionCollection());
 
     // Menu
-    d->m_buttonMenuAction = new KToolBarPopupAction(QIcon::fromTheme("configure"), "", this);
+    d->m_buttonMenuAction = new KToolBarPopupAction(SKGServices::fromTheme("configure"), "", this);
     d->m_buttonMenuAction->setToolTip(i18nc("Noun, user action", "Menu"));
     d->m_buttonMenu = static_cast<QMenu*>(d->m_buttonMenuAction->menu());
     connect(d->m_buttonMenu , &QMenu::aboutToShow, this, &SKGMainPanel::onShowButtonMenu);
@@ -989,11 +986,11 @@ void SKGMainPanel::setupActions()
     d->m_showMenuBarAction = KStandardAction::showMenubar(this, SLOT(onShowMenuBar()), actionCollection());
     KConfigGroup pref = getMainConfigGroup();
     d->m_showMenuBarAction->setChecked(pref.readEntry("menubar_shown", true));
-    QTimer::singleShot(200, Qt::CoarseTimer, this, SLOT(onShowMenuBar()));
+    QTimer::singleShot(200, Qt::CoarseTimer, this, &SKGMainPanel::onShowMenuBar);
     registerGlobalAction("options_show_menubar", d->m_showMenuBarAction);
 
     //
-    d->m_previousAction = new KToolBarPopupAction(QIcon::fromTheme("go-previous"), i18nc("Noun, user action", "Previous"), this);
+    d->m_previousAction = new KToolBarPopupAction(SKGServices::fromTheme("go-previous"), i18nc("Noun, user action", "Previous"), this);
     connect(d->m_previousAction, &QAction::triggered, this, &SKGMainPanel::onPrevious);
     actionCollection()->setDefaultShortcut(d->m_previousAction, Qt::ALT + Qt::Key_Left);
     d->m_previousAction->setPriority(QAction::LowPriority);
@@ -1004,7 +1001,7 @@ void SKGMainPanel::setupActions()
     registerGlobalAction("go_previous", d->m_previousAction);
 
     //
-    d->m_nextAction = new KToolBarPopupAction(QIcon::fromTheme("go-next"), i18nc("Noun, user action", "Next"), this);
+    d->m_nextAction = new KToolBarPopupAction(SKGServices::fromTheme("go-next"), i18nc("Noun, user action", "Next"), this);
     connect(d->m_nextAction, &QAction::triggered, this, &SKGMainPanel::onNext);
     actionCollection()->setDefaultShortcut(d->m_nextAction, Qt::ALT + Qt::Key_Right);
     d->m_nextAction->setPriority(QAction::LowPriority);
@@ -1019,14 +1016,14 @@ void SKGMainPanel::setupActions()
     registerGlobalAction("fullscreen", d->m_fullScreenAction);
 
     //
-    d->m_enableEditorAction = new QAction(QIcon::fromTheme("appointment-new"), i18nc("Noun, user action", "Enable editor"), this);
+    d->m_enableEditorAction = new QAction(SKGServices::fromTheme("appointment-new"), i18nc("Noun, user action", "Enable editor"), this);
     actionCollection()->setDefaultShortcut(d->m_enableEditorAction, Qt::CTRL + Qt::Key_Insert);
     connect(d->m_enableEditorAction, &QAction::triggered, this, &SKGMainPanel::enableEditor);
     registerGlobalAction("enable_editor", d->m_enableEditorAction);
 
 #ifdef SKGCIPHER
     //
-    QAction* migrateSQLCipher = new QAction(QIcon::fromTheme("run-build"), i18nc("Noun, user action", "Migrate to SQLCipher format"), this);
+    QAction* migrateSQLCipher = new QAction(SKGServices::fromTheme("run-build"), i18nc("Noun, user action", "Migrate to SQLCipher format"), this);
     connect(migrateSQLCipher, &QAction::triggered, this, &SKGMainPanel::onMigrateToSQLCipher);
     registerGlobalAction("migrate_sqlcipher", migrateSQLCipher);
 #endif
@@ -1116,7 +1113,7 @@ void SKGMainPanel::onShowPreviousMenu()
             QList<SKGTabPage::SKGPageHistoryItem> list = cPage->getPreviousPages();
             int nb = list.count();
             for (int i = 0; i < nb; ++i) {
-                QAction* act = d->m_previousMenu->addAction(QIcon::fromTheme(list.at(i).icon), list.at(i).name);
+                QAction* act = d->m_previousMenu->addAction(SKGServices::fromTheme(list.at(i).icon), list.at(i).name);
                 if (act) {
                     act->setData(i);
                     connect(act, &QAction::triggered, this, &SKGMainPanel::onPrevious);
@@ -1292,7 +1289,7 @@ void SKGMainPanel::onShowNextMenu()
             QList<SKGTabPage::SKGPageHistoryItem> list = cPage->getNextPages();
             int nb = list.count();
             for (int i = 0; i < nb; ++i) {
-                QAction* act = d->m_nextMenu->addAction(QIcon::fromTheme(list.at(i).icon), list.at(i).name);
+                QAction* act = d->m_nextMenu->addAction(SKGServices::fromTheme(list.at(i).icon), list.at(i).name);
                 if (act) {
                     act->setData(i);
                     connect(act, &QAction::triggered, this, &SKGMainPanel::onNext);
@@ -1360,7 +1357,7 @@ bool SKGMainPanel::queryFileClose()
             if (!d->m_saveOnClose) code = KMessageBox::questionYesNoCancel(this, i18nc("Question", "The document has been modified.\nDo you want to save it before closing?"),
                                               QString(),
                                               KGuiItem(fileName.isEmpty() ?  i18nc("Question", "Save as") : i18nc("Question", "Save"),
-                                                       QIcon::fromTheme(fileName.isEmpty() ?  "document-save-as" : "document-save")),
+                                                       SKGServices::fromTheme(fileName.isEmpty() ?  "document-save-as" : "document-save")),
                                               KGuiItem(i18nc("Question", "Do not save")));
             if (code == KMessageBox::Yes) {
                 save->trigger();
@@ -1450,9 +1447,9 @@ void SKGMainPanel::optionsPreferences(const QString& iPluginName)
     }
 
     // Synchronize setting with confirmation panel
-    {
+    if (skgbasegui_settings::update_modified_bookmarks() == 0) {
         KMessageBox::ButtonCode confirm;
-        int ask = KMessageBox::shouldBeShownYesNo("updateBookmarkOnClose", confirm);
+        bool ask = KMessageBox::shouldBeShownYesNo("updateBookmarkOnClose", confirm);
 
         KConfigGroup pref = getMainConfigGroup();
         if (ask) {
@@ -1463,9 +1460,10 @@ void SKGMainPanel::optionsPreferences(const QString& iPluginName)
             pref.writeEntry("update_modified_bookmarks", 2);
         }
     }
-    {
+
+    if (skgbasegui_settings::update_modified_contexts() == 0) {
         KMessageBox::ButtonCode confirm;
-        int ask = KMessageBox::shouldBeShownYesNo("updateContextOnClose", confirm);
+        bool ask = KMessageBox::shouldBeShownYesNo("updateContextOnClose", confirm);
 
         KConfigGroup pref = getMainConfigGroup();
         if (ask) {
@@ -1822,13 +1820,13 @@ SKGTabPage* SKGMainPanel::openPage(SKGInterfacePlugin* plugin, int index, const
 
             if (index == -1) {
                 SKGTRACEINFUNC(20);
-                d->m_tabWidget->addTab(w, QIcon::fromTheme(plugin->icon()), title2);
+                d->m_tabWidget->addTab(w, SKGServices::fromTheme(plugin->icon()), title2);
                 if (iSetCurrent) {
                     d->m_tabWidget->setCurrentWidget(w);
                 }
             } else {
                 SKGTRACEINFUNC(20);
-                d->m_tabWidget->insertTab(index, w, QIcon::fromTheme(plugin->icon()), title2);
+                d->m_tabWidget->insertTab(index, w, SKGServices::fromTheme(plugin->icon()), title2);
                 if (iSetCurrent) {
                     d->m_tabWidget->setCurrentWidget(w);
                 }
@@ -2288,7 +2286,7 @@ KMessageWidget* SKGMainPanel::displayMessage(const QString& iMessage, SKGDocumen
         msg = new KMessageWidget(this);
         msg->setText(iMessage);
         msg->setMessageType(static_cast<KMessageWidget::MessageType>(iType));
-        QTimer::singleShot(iType == SKGDocument::Positive ? 5000 : iType == SKGDocument::Information ? 10000 : 20000, Qt::CoarseTimer, msg, SLOT(deleteLater()));
+        QTimer::singleShot(iType == SKGDocument::Positive ? 5000 : iType == SKGDocument::Information ? 10000 : 20000, Qt::CoarseTimer, msg, &KMessageWidget::deleteLater);
         d->m_mainLayout->insertWidget(qMax(d->m_mainLayout->indexOf(d->m_mainWidget) - 1, 0), msg);
 
         if (!iAction.isEmpty()) {
@@ -2358,7 +2356,7 @@ KMessageWidget* SKGMainPanel::displayErrorMessage(const SKGError& iError, QActio
             // Add history action in case of
             if (iError.getHistoricalSize()) {
                 QAction* history = new QAction(i18nc("Noun", "History"), msg);
-                history->setIcon(QIcon::fromTheme("dialog-information"));
+                history->setIcon(SKGServices::fromTheme("dialog-information"));
                 history->setData(iError.getFullMessageWithHistorical());
                 msg->addAction(history);
                 connect(history, &QAction::triggered, parent, [ = ] { parent->displayErrorMessage();});
@@ -2416,7 +2414,7 @@ QString SKGMainPanel::getSaveFileName(const QString& startDir, const QString& fi
     if (f.exists() && KMessageBox::warningContinueCancel(iParent,
             i18nc("Question", "File <b>%1</b> already exists. Do you really want to overwrite it?", fileName),
             i18nc("Question", "Warning"),
-            KGuiItem(i18nc("Verb",  "Save"), QIcon::fromTheme("document-save"))) != KMessageBox::Continue) {
+            KGuiItem(i18nc("Verb",  "Save"), SKGServices::fromTheme("document-save"))) != KMessageBox::Continue) {
         return "";
     }
 
@@ -2559,21 +2557,35 @@ void SKGMainPanel::onMigrateToSQLCipher()
         QString output = input % "_migrated.skg";
         output = output.replace(".skg_migrated", "_migrated");
 
+        // Build argument
+        QStringList arg;
+        arg.push_back("--in");
+        arg.push_back(input);
+        arg.push_back("--out");
+        arg.push_back(tmp);
+
+
         QString password = getDocument()->getParameter("SKG_PASSWORD");
         if (!password.isEmpty()) {
+            arg.push_back("--param");
+            arg.push_back("password");
+            arg.push_back("--value");
+            arg.push_back(password);
             password = " --param password --value \"" % password % "\"";
         }
 
         // Convertion skg => sqlcipher
         QString cmd = "skroogeconvert --in \"" % input % "\" --out \"" % tmp % "\"" % password;
-        int rc = QProcess::execute(cmd);
+        int rc = QProcess::execute("skroogeconvert", arg);
         if (rc != 0) {
-            err.setReturnCode(ERR_FAIL).setMessage(i18nc("Error message",  "The following command line failed:\n'%1'", cmd));
+            err.setReturnCode(ERR_FAIL).setMessage(i18nc("Error message",  "The following command line failed with code %2:\n'%1'", cmd, rc));
         } else {
             cmd = "skroogeconvert --in \"" % tmp % "\" --out \"" % output % "\"" % password;
-            rc = QProcess::execute(cmd);
+            arg[1] = tmp;
+            arg[3] = output;
+            rc = QProcess::execute("skroogeconvert", arg);
             if (rc != 0) {
-                err.setReturnCode(ERR_FAIL).setMessage(i18nc("Error message",  "The following command line failed:\n'%1'", cmd));
+                err.setReturnCode(ERR_FAIL).setMessage(i18nc("Error message",  "The following command line failed with code %2:\n'%1'", cmd, rc));
             } else {
                 getDocument()->sendMessage(i18nc("Positive message", "You document has been migrated.\nHere is the new file:\n%1", output), SKGDocument::Positive, "skg://file_open/?filename=" % output);
                 notify();
