@@ -180,7 +180,7 @@ public Q_SLOTS:
      * To know if the closure of the application is authorized
      * @return true if close is authorized else false
      */
-    virtual bool queryClose();
+    virtual bool queryClose() Q_DECL_OVERRIDE;
 
     /**
      * To know if the closure of the file is authorized
@@ -463,14 +463,14 @@ protected:
      * event
      * @param e event
      */
-    virtual void changeEvent(QEvent* e);
+    virtual void changeEvent(QEvent* e) Q_DECL_OVERRIDE;
     /**
      * Event filtering
      * @param iObject object
      * @param iEvent event
      * @return In your reimplementation of this function, if you want to filter the event out, i.e. stop it being handled further, return true; otherwise return false.
      */
-    virtual bool eventFilter(QObject* iObject, QEvent* iEvent);
+    virtual bool eventFilter(QObject* iObject, QEvent* iEvent) Q_DECL_OVERRIDE;
 
 private Q_SLOTS:
     void showMenu(const QPoint& iPos);
