@@ -37,6 +37,7 @@
 #include "skgdocument.h"
 #include "skgnodeobject.h"
 #include "skgtransactionmng.h"
+#include <skgpropertyobject.h>
 #include "skgmainpanel.h"
 
 SKGObjectModelBase::SKGObjectModelBase(SKGDocument* iDocument,
@@ -201,6 +202,7 @@ void SKGObjectModelBase::buidCache()
     SKGTRACEINFUNC(1);
     m_doctransactionTable = (getRealTable() == "doctransaction");
     m_nodeTable = (getRealTable() == "node");
+    m_parametersTable = (getRealTable() == "parameters");
 
     // Get std colors
     KColorScheme scheme(QPalette::Normal);
@@ -590,7 +592,6 @@ SKGObjectBase SKGObjectModelBase::getObject(const QModelIndex& iIndex) const
 SKGObjectBase* SKGObjectModelBase::getObjectPointer(const QModelIndex& iIndex) const
 {
     _SKGTRACEINFUNC(10);
-    // SKGTRACE << "getObject:" << index.internalId() << endl;
     return m_objectsHashTable.value(iIndex.internalId());
 }
 
@@ -706,6 +707,17 @@ QVariant SKGObjectModelBase::data(const QModelIndex& iIndex, int iRole) const
             }
             return "";
         }
+
+        int propertyId = data(iIndex, 101).toInt();
+        if (propertyId) {
+            SKGPropertyObject p(m_document, propertyId);
+            if (!p.getUrl().scheme().isEmpty()) {
+                QFont f;
+                f.setUnderline(true);
+
+                return QVariant::fromValue(f);
+            }
+        }
         break;
     }
     case Qt::TextColorRole: {
@@ -718,6 +730,15 @@ QVariant SKGObjectModelBase::data(const QModelIndex& iIndex, int iRole) const
                 return m_fontNegativeColor;
             }
         }
+
+        int propertyId = data(iIndex, 101).toInt();
+        if (propertyId) {
+            SKGPropertyObject p(m_document, propertyId);
+            if (!p.getUrl().scheme().isEmpty()) {
+                KColorScheme scheme(QPalette::Normal);
+                return QVariant::fromValue(scheme.foreground(KColorScheme::ActiveText).color());
+            }
+        }
         break;
     }
     case Qt::TextAlignmentRole: {
@@ -732,7 +753,7 @@ QVariant SKGObjectModelBase::data(const QModelIndex& iIndex, int iRole) const
         if (obj->getTable().isEmpty()) {
             // This is a group
             if (iIndex.column() == 0) {
-                return QVariant::fromValue(QIcon::fromTheme("arrow-right"));
+                return QVariant::fromValue(SKGServices::fromTheme("arrow-right"));
             };
             return "";
         } else {
@@ -740,10 +761,10 @@ QVariant SKGObjectModelBase::data(const QModelIndex& iIndex, int iRole) const
                 SKGNodeObject node(*obj);
                 return QVariant::fromValue(node.getIcon());
             } else if (iIndex.column() == 0 && m_doctransactionTable) {
-                return QVariant::fromValue(QIcon::fromTheme(obj->getAttribute("t_mode") == "U" ? "edit-undo" : "edit-redo"));
+                return QVariant::fromValue(SKGServices::fromTheme(obj->getAttribute("t_mode") == "U" ? "edit-undo" : "edit-redo"));
             } else if (m_doctransactionTable && att == "t_savestep") {
                 if (obj->getAttribute("t_savestep") == "Y") {
-                    return QVariant::fromValue(QIcon::fromTheme("document-save"));
+                    return QVariant::fromValue(SKGServices::fromTheme("document-save"));
                 }
             }
         }
@@ -804,9 +825,25 @@ QVariant SKGObjectModelBase::data(const QModelIndex& iIndex, int iRole) const
         if (obj) {
             return SKGServices::stringToDouble(obj->getAttribute("f_sortorder"));
         }
-
         break;
     }
+    case 101: {
+        SKGObjectBase* obj = getObjectPointer(iIndex);
+        // Is it a URL ?
+        QString att = m_listAttibutes.at(iIndex.column());
+        if (att.startsWith(QLatin1String("p_"))) {
+            SKGPropertyObject p(obj->getPropertyObject(att.right(att.count() - 2)));
+            if (!p.getUrl().scheme().isEmpty()) {
+                return QVariant::fromValue(p.getID());
+            }
+        } else if (m_parametersTable && att == "t_value") {
+            SKGPropertyObject p(*obj);
+            if (!p.getUrl().scheme().isEmpty()) {
+                return QVariant::fromValue(p.getID());
+            }
+        }
+        return 0;
+    }
     default : {
     }
     }
@@ -879,7 +916,7 @@ Qt::DropActions SKGObjectModelBase::supportedDragActions() const
 
 Qt::DropActions SKGObjectModelBase::supportedDropActions() const
 {
-    return Qt::MoveAction | Qt::LinkAction;
+    return Qt::MoveAction | Qt::LinkAction | Qt::CopyAction;
 }
 
 QStringList SKGObjectModelBase::mimeTypes() const
@@ -944,7 +981,11 @@ bool SKGObjectModelBase::dropMimeData(const QMimeData* iData,
                     idx++;
                     name = i18n("File") % " (" % SKGServices::intToString(idx) % ')';
                 }
-                err = obj.setProperty(name, urls.at(i).toLocalFile(), iAction == Qt::LinkAction ? "" : urls.at(i).toLocalFile());
+                QString f = urls.at(i).toLocalFile();
+                err = obj.setProperty(name, f, iAction == Qt::LinkAction ? "" : f);
+                if (!err && iAction == Qt::MoveAction) {
+                    QFile(f).remove();
+                }
                 IFOKDO(err, getDocument()->stepForward(i + 1))
             }
         }
