@@ -59,7 +59,7 @@ void SKGTabWidget::onCurrentChanged()
     if (currentWidget() && !m_tabIndexSaveButton.keys().contains(currentWidget())) {
         // Build widgets
         QPushButton* kSave = new QPushButton(this);
-        kSave->setIcon(QIcon::fromTheme("document-save"));
+        kSave->setIcon(SKGServices::fromTheme("document-save"));
         kSave->setToolTip(i18nc("Verb", "Save this tab"));
         kSave->setFlat(true);
         kSave->setMaximumSize(QSize(16, 16));
@@ -72,7 +72,7 @@ void SKGTabWidget::onCurrentChanged()
     }
 
     // Rebuild indexes
-    QMap<QWidget*, QPushButton*> TabIndexSaveButton2;
+    QHash<QWidget*, QPushButton*> TabIndexSaveButton2;
 
     int nb = count();
     for (int i = 0; i < nb; ++i) {
@@ -133,7 +133,7 @@ void SKGTabWidget::onRefreshSaveIcon()
             } else if (page->isPin()) {
                 save->show();
                 save->setEnabled(false);
-                save->setIcon(QIcon::fromTheme("document-encrypt"));
+                save->setIcon(SKGServices::fromTheme("document-encrypt"));
             } else {
                 save->hide();
             }
