@@ -23,7 +23,7 @@
  */
 #include <QTabWidget>
 
-#include <qmap.h>
+#include <QHash>
 #include <qtimer.h>
 
 #include "skgbasegui_export.h"
@@ -65,7 +65,7 @@ private Q_SLOTS:
 private:
     QTimer m_timerSave;
 
-    QMap<QWidget*, QPushButton*> m_tabIndexSaveButton;
+    QHash<QWidget*, QPushButton*> m_tabIndexSaveButton;
 };
 
 #endif  // SKGTABWIDGET_H
