@@ -60,6 +60,7 @@
 #include "skgtableview.h"
 #include "skgtraces.h"
 #include "skgtransactionmng.h"
+#include "skgpropertyobject.h"
 
 SKGTreeView::SKGTreeView(QWidget* iParent)
     : QTreeView(iParent),
@@ -96,13 +97,13 @@ SKGTreeView::SKGTreeView(QWidget* iParent)
     actCopy->setProperty("isShortcutConfigurable", false);
     actCopy->setShortcutContext(Qt::WidgetShortcut);
 
-    m_actExpandAll = new QAction(QIcon::fromTheme("format-indent-more"), i18nc("Noun, user action", "Expand all"), this);
+    m_actExpandAll = new QAction(SKGServices::fromTheme("format-indent-more"), i18nc("Noun, user action", "Expand all"), this);
     m_actExpandAll->setShortcut(Qt::ALT + Qt::Key_Plus);
     m_actExpandAll->setProperty("isShortcutConfigurable", false);
     m_actExpandAll->setShortcutContext(Qt::WidgetShortcut);
     connect(m_actExpandAll, &QAction::triggered, this, &SKGTreeView::expandAll);
 
-    m_actCollapseAll = new QAction(QIcon::fromTheme("format-indent-less"), i18nc("Noun, user action", "Collapse all"), this);
+    m_actCollapseAll = new QAction(SKGServices::fromTheme("format-indent-less"), i18nc("Noun, user action", "Collapse all"), this);
     m_actCollapseAll->setShortcut(Qt::ALT + Qt::Key_Minus);
     m_actCollapseAll->setProperty("isShortcutConfigurable", false);
     m_actCollapseAll->setShortcutContext(Qt::WidgetShortcut);
@@ -455,7 +456,7 @@ void SKGTreeView::setupHeaderMenu()
     if (m_model && m_headerMenu) {
         // Corner button on tables to show the contextual menu
         QPushButton* btn = new QPushButton(this);
-        btn->setIcon(QIcon::fromTheme("configure"));
+        btn->setIcon(SKGServices::fromTheme("configure"));
         connect(btn, &QPushButton::clicked, this, static_cast<void (SKGTreeView::*)()>(&SKGTreeView::showHeaderMenu));
         setCornerWidget(btn);
 
@@ -472,7 +473,7 @@ void SKGTreeView::setupHeaderMenu()
             groupby = new QActionGroup(groupbymenu);
             m_actGroupByNone = groupbymenu->addAction(i18nc("Noun, grouping option", "None"));
             if (m_actGroupByNone) {
-                m_actGroupByNone->setIcon(QIcon::fromTheme("dialog-cancel"));
+                m_actGroupByNone->setIcon(SKGServices::fromTheme("dialog-cancel"));
                 m_actGroupByNone->setCheckable(true);
                 m_actGroupByNone->setChecked(m_groupby.isEmpty());
                 m_actGroupByNone->setData("");
@@ -481,7 +482,7 @@ void SKGTreeView::setupHeaderMenu()
             if (m_proxyModel) {
                 QAction* actSort = groupbymenu->addAction(i18nc("Noun, grouping option", "Sorted column"));
                 if (actSort) {
-                    actSort->setIcon(QIcon::fromTheme("view-sort-ascending"));
+                    actSort->setIcon(SKGServices::fromTheme("view-sort-ascending"));
                     actSort->setCheckable(true);
                     actSort->setChecked(m_groupby == "#");
                     actSort->setData("#");
@@ -496,13 +497,13 @@ void SKGTreeView::setupHeaderMenu()
             QList<SKGDocument::SKGModelTemplate> schemas = m_model->getSchemas();
             int nbSchemas = schemas.count();
             if (nbSchemas) {
-                QMenu* viewAppearanceMenu = columns->addMenu(QIcon::fromTheme("view-file-columns"), i18nc("Noun, user action", "View appearance"));
+                QMenu* viewAppearanceMenu = columns->addMenu(SKGServices::fromTheme("view-file-columns"), i18nc("Noun, user action", "View appearance"));
 
                 for (int i = 0; i < nbSchemas; ++i) {
                     SKGDocument::SKGModelTemplate schema = schemas.at(i);
                     QAction* act = viewAppearanceMenu->addAction(schema.name);
                     if (!schema.icon.isEmpty()) {
-                        act->setIcon(QIcon::fromTheme(schema.icon));
+                        act->setIcon(SKGServices::fromTheme(schema.icon));
                     }
                     act->setData(schema.schema);
 
@@ -511,7 +512,7 @@ void SKGTreeView::setupHeaderMenu()
             }
         }
 
-        QAction* actResize = columns->addAction(QIcon::fromTheme("zoom-fit-width"), i18nc("Noun, user action", "Resize to content"));
+        QAction* actResize = columns->addAction(SKGServices::fromTheme("zoom-fit-width"), i18nc("Noun, user action", "Resize to content"));
         connect(actResize, &QAction::triggered, this, &SKGTreeView::resizeColumnsToContents);
 
         m_actAutoResize = columns->addAction(SKGServices::fromTheme("zoom-fit-width", QStringList() << "run-build"), i18nc("Noun, user action", "Auto resize"));
@@ -527,7 +528,7 @@ void SKGTreeView::setupHeaderMenu()
         }
 
         if (m_document) {
-            QAction* actDefault = m_headerMenu->addAction(QIcon::fromTheme("document-save"), i18nc("Noun, user action", "Save parameters"));
+            QAction* actDefault = m_headerMenu->addAction(SKGServices::fromTheme("document-save"), i18nc("Noun, user action", "Save parameters"));
             connect(actDefault, &QAction::triggered, this, &SKGTreeView::saveDefaultClicked);
         }
 
@@ -586,7 +587,7 @@ void SKGTreeView::setupHeaderMenu()
         }
         m_headerMenu->addSeparator();
 
-        QAction* actExport = m_headerMenu->addAction(QIcon::fromTheme("document-export"), i18nc("Noun, user action", "Export..."));
+        QAction* actExport = m_headerMenu->addAction(SKGServices::fromTheme("document-export"), i18nc("Noun, user action", "Export..."));
         connect(actExport, &QAction::triggered, this, &SKGTreeView::onExport);
 
         if (m_autoResize) {
@@ -1032,6 +1033,15 @@ void SKGTreeView::mousePressEvent(QMouseEvent* iEvent)
         Q_EMIT clickEmptyArea();
         clearSelection();
     }
+
+    if (iEvent && iEvent->button() == Qt::LeftButton && m_proxyModel && m_model) {
+        int propertyUUID = m_proxyModel->data(indexAt(iEvent->pos()), 101).toInt();
+        if (propertyUUID) {
+            SKGPropertyObject prop(m_model->getDocument(), propertyUUID);
+            QDesktopServices::openUrl(prop.getUrl(true));
+        }
+    }
+
     QTreeView::mousePressEvent(iEvent);
 }
 
@@ -1253,7 +1263,7 @@ void SKGTreeView::onExport()
     if (!fileName.isEmpty()) {
         SKGError err = exportInFile(fileName);
         SKGMainPanel::displayErrorMessage(err);
-        QDesktopServices::openUrl(QUrl(fileName));
+        QDesktopServices::openUrl(QUrl::fromLocalFile(fileName));
     }
 }
 
