@@ -22,11 +22,10 @@
  * @author Stephane MANKOWSKI / Guillaume DE BURE
  */
 #include <qstringlist.h>
-#include <QTreeView>
-
-
+#include <qtreeview.h>
 #include <qmenu.h>
 
+#include "skgtraces.h"
 #include "skgservices.h"
 #include "skgobjectbase.h"
 #include "skgbasegui_export.h"
@@ -38,6 +37,7 @@ class QTextBrowser;
 class SKGSortFilterProxyModel;
 class QTimer;
 
+
 /**
  * This file is a tab widget used by plugins
  */
@@ -130,7 +130,7 @@ public:
      * Sets the current selection model to the given selectionModel.
      * @param iSelectionModel the selection model
      */
-    virtual void setSelectionModel(QItemSelectionModel* iSelectionModel);
+    virtual void setSelectionModel(QItemSelectionModel* iSelectionModel) Q_DECL_OVERRIDE;
 
     /**
      * Insert a registered action
@@ -145,7 +145,7 @@ public:
      * @param iModel the model
      * @return void
      **/
-    virtual void setModel(QAbstractItemModel* iModel);
+    virtual void setModel(QAbstractItemModel* iModel) Q_DECL_OVERRIDE;
 
     /**
      * @brief Get the header menu
@@ -190,7 +190,7 @@ protected:
      * If a valid item is pressed on it is made into the current item. This function emits the pressed() signal.
      * @param iEvent the event
      */
-    virtual void mousePressEvent(QMouseEvent* iEvent);
+    virtual void mousePressEvent(QMouseEvent* iEvent) Q_DECL_OVERRIDE;
 
 public Q_SLOTS:
     /**
@@ -293,7 +293,7 @@ protected:
       * @param iEvent event
       * @return In your reimplementation of this function, if you want to filter the event out, i.e. stop it being handled further, return true; otherwise return false.
       */
-    virtual bool eventFilter(QObject* iObject, QEvent* iEvent);
+    virtual bool eventFilter(QObject* iObject, QEvent* iEvent) Q_DECL_OVERRIDE;
 
 private Q_SLOTS:
     void onExport();
