@@ -90,12 +90,12 @@ void SKGWebView::contextMenuEvent(QContextMenuEvent* iEvent)
 
         menu->addAction(pageAction(QWebPage::Copy));
 
-        QAction* actPrint = menu->addAction(QIcon::fromTheme("printer"), i18nc("Action", "Print..."));
+        QAction* actPrint = menu->addAction(SKGServices::fromTheme("printer"), i18nc("Action", "Print..."));
         connect(actPrint, &QAction::triggered, this, &SKGWebView::onPrint);
 
         menu->addAction(static_cast<QAction*>(KStandardAction::printPreview(this, SLOT(onPrintPreview()), this)));
 
-        QAction* actExport = menu->addAction(QIcon::fromTheme("document-export"), i18nc("Noun, user action", "Export..."));
+        QAction* actExport = menu->addAction(SKGServices::fromTheme("document-export"), i18nc("Noun, user action", "Export..."));
         connect(actExport, &QAction::triggered, this, &SKGWebView::onExport);
 
         menu->popup(this->mapToGlobal(iEvent->pos()));
