@@ -92,7 +92,7 @@ public:
     * Operator affectation
     * @param iAdvice the advice to copy
     */
-    SKGAdvice& operator= (const SKGAdvice& iAdvice);
+    virtual SKGAdvice& operator= (const SKGAdvice& iAdvice);
 
 public Q_SLOTS:
     /**
