@@ -450,7 +450,7 @@ public Q_SLOTS:
      * @param iParentUUID the unique identifier of the object owning this parameter.
      * @return the value.
      */
-    virtual QString getParameter(const QString& iName, const QString& iParentUUID = "document");
+    virtual QString getParameter(const QString& iName, const QString& iParentUUID = QLatin1String("document"));
 
     /**
      * Get a parameter blob
@@ -458,7 +458,7 @@ public Q_SLOTS:
      * @param iParentUUID the unique identifier of the object owning this parameter.
      * @return the blob.
      */
-    virtual QVariant getParameterBlob(const QString& iName, const QString& iParentUUID = "document");
+    virtual QVariant getParameterBlob(const QString& iName, const QString& iParentUUID = QLatin1String("document"));
 
     /**
      * Set a parameter.
@@ -530,7 +530,7 @@ public Q_SLOTS:
                                          const QString& iOpAtt,
                                          const QString& iWhereClause,
                                          SKGStringListList& oTable,
-                                         const QString& iMissingValue = "0");
+                                         const QString& iMissingValue = QLatin1String("0"));
 
     /**
      * Refresh all views and indexes in the database
