@@ -77,7 +77,7 @@ public:
      * Operator affectation
      * @param iObject the object to copy
      */
-    virtual const SKGNamedObject& operator= (const SKGObjectBase& iObject);
+    virtual const SKGNamedObject& operator= (const SKGObjectBase& iObject) Q_DECL_OVERRIDE;
 
     /**
      * Destructor
