@@ -30,6 +30,7 @@
 
 #include "skgdocument.h"
 #include "skgnamedobject.h"
+#include "skgservices.h"
 #include "skgtraces.h"
 
 /**
@@ -475,7 +476,7 @@ SKGError SKGObjectBase::remove(bool iSendMessage, bool iForce) const
     return err;
 }
 
-SKGError SKGObjectBase::dump()
+SKGError SKGObjectBase::dump() const
 {
     // dump
     SKGTRACE << "=== START DUMP [" << getUniqueID() << "]===" << endl;
@@ -497,6 +498,16 @@ QString SKGObjectBase::getProperty(const QString& iName) const
     return Q_UNLIKELY(!getDocument()) ? QString() : getDocument()->getParameter(iName, getUniqueID());
 }
 
+SKGObjectBase SKGObjectBase::getPropertyObject(const QString& iName) const
+{
+    SKGObjectBase property;
+    if (getDocument()) {
+        getDocument()->getObject("parameters", "t_name='" % SKGServices::stringToSqlString(iName) %
+                                 "' AND t_uuid_parent='" % SKGServices::stringToSqlString(getUniqueID()) % '\'', property);
+    }
+    return property;
+}
+
 QVariant SKGObjectBase::getPropertyBlob(const QString& iName) const
 {
     return Q_UNLIKELY(!getDocument()) ? QVariant() : getDocument()->getParameterBlob(iName, getUniqueID());
