@@ -598,7 +598,8 @@ QString SKGServices::getDateFormat(const QStringList& iDates)
     for (int i = 0; i < nb; ++i) {
         QString val = iDates.at(i).trimmed();
         if (val.count() > 10) {
-            val = SKGServices::splitCSVLine(val, ' ')[0];
+            auto l = SKGServices::splitCSVLine(val, ' ');
+            val = l[0];
         }
         if (!val.isEmpty()) {
             val = val.replace(' ', '0');
@@ -786,7 +787,8 @@ QString SKGServices::dateToSqlString(const QString& iDate, const QString& iForma
 {
     QString input = iDate;
     if (input.count() > 10) {
-        input = SKGServices::splitCSVLine(input, ' ')[0];
+        auto l = SKGServices::splitCSVLine(input, ' ');
+        input = l[0];
     }
 
     QString format = "yyyy-MM-dd";
@@ -1773,10 +1775,16 @@ QString SKGServices::encodeForUrl(const QString& iString)
 
 QIcon SKGServices::fromTheme(const QString& iName, const QStringList& iOverlays)
 {
+    QIcon output;
     if (iOverlays.count() > 0) {
-        return QIcon(new KIconEngine(iName,  KIconLoader::global(), iOverlays));
+        output = QIcon(new KIconEngine(iName,  KIconLoader::global(), iOverlays));
+    } else {
+        output = QIcon(new KIconEngine(iName,  KIconLoader::global()));
     }
-    return QIcon::fromTheme(iName);
+    if (output.isNull() && !iName.isEmpty()) {
+        SKGTRACE << "WARNING: Icon [" << iName << "] not found" << endl;
+    }
+    return output;
 }
 
 QString SKGServices::getMajorVersion(const QString& iVersion)
@@ -1791,5 +1799,3 @@ QString SKGServices::getMajorVersion(const QString& iVersion)
     }
     return output;
 }
-
-
