@@ -617,7 +617,7 @@ public:
      * @param iOverlays List of overlays
      * @return The icon
      */
-    static QIcon fromTheme(const QString& iName, const QStringList& iOverlays);
+    static QIcon fromTheme(const QString& iName, const QStringList& iOverlays = QStringList());
 
     /**
      * Get a major version (ex: 4.3) of a version (ex: 4.3.1)
