@@ -61,6 +61,8 @@ int main(int argc, char** argv)
         SKGTESTERROR("ACCOUNT.getObjectByName", SKGNamedObject::getObjectByName(&document1, "v_account", "Courant steph", account), true);
         SKGTESTERROR("ACCOUNT.load", account.load(), true);
         SKGTEST("ACCOUNT:getCurrentAmount", SKGServices::doubleToString(account.getCurrentAmount()), "-935");
+        SKGTEST("document1:getCategoryForPayee", document1.getCategoryForPayee("Anthony Hopkins"), "Entertain > Movie");
+        SKGTEST("document1:getCategoryForPayee", document1.getCategoryForPayee("NOT FOUND"), "");
     }
 
     {
