@@ -211,7 +211,7 @@ int main(int argc, char** argv)
                     SKGTESTBOOL("OPE:comparison", (opget == op_1), true);
 
                     SKGSubOperationObject subop_12 = subop_1;
-                    SKGSubOperationObject subop_13(SKGObjectBase(subop_1));
+                    SKGSubOperationObject subop_13((SKGObjectBase(subop_1)));
                     SKGSubOperationObject subop_14 = SKGSubOperationObject(subop_1);
 
                     SKGObjectBase subop_base = subop_1;
